<?php

namespace App\Http\Controllers\Admin;

use Carbon\Carbon;
use App\Models\Ptc;
use App\Models\Fund;
use App\Models\Plan;
use App\Models\User;
use App\Models\Ticket;
use App\Models\Gateway;
use App\Models\PtcView;
use App\Models\PayoutLog;
use App\Http\Traits\Upload;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Models\ReferralBonus;
use App\Rules\FileTypeValidate;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use \Illuminate\Support\Facades\Auth;
use Stevebauman\Purify\Facades\Purify;
use \Illuminate\Support\Facades\Validator;

class DashboardController extends Controller
{
    use Upload;

    public $user;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->user = Auth::guard('admin')->user();
            return $next($request);
        });
    }
    public function forbidden()
    {
        return view('admin.errors.403');
    }


    public function dashboard()
    {
        $data['totalActivePlan'] = Plan::where('status', 1)->count();


        $data['ads'] = collect(Ptc::selectRaw('COUNT(id) AS totalAds')
        ->selectRaw('COUNT(CASE WHEN remaining > 0 AND status = 1  THEN id END) AS todayActiveAds')
            ->selectRaw('COUNT(CASE WHEN status = 0 THEN id END) AS totalDeactiveAds')
            ->selectRaw('COUNT(CASE WHEN status = 2 THEN id END) AS totalPendingAds')
            ->selectRaw('COUNT(CASE WHEN status = 3 THEN id END) AS totalRejectedAds')
            ->get()->toArray())->collapse();

        $data['ptcView'] = collect(PtcView::selectRaw('COUNT(id) AS totalViewedAds')
            ->selectRaw('COUNT((CASE WHEN ad_view_date = CURDATE() THEN id END)) AS todayViewedAds')
            ->get()->toArray())->collapse();




        $data['bonus'] = collect(ReferralBonus::selectRaw("SUM(CASE WHEN `type` = 'deposit' THEN amount END) AS refDepositBonus")
            ->selectRaw("SUM(CASE WHEN `type` = 'invest' THEN amount END) AS refPlanPurchaseBonus")
            ->selectRaw("SUM(CASE WHEN `type` = 'ptc' THEN amount END) AS refPTCBonus")
            ->selectRaw("SUM((CASE WHEN created_at = CURDATE() AND `type` = 'deposit'  THEN amount END)) AS todayRefDepositBonus")
            ->selectRaw("SUM((CASE WHEN created_at = CURDATE() AND `type` = 'invest'  THEN amount END)) AS todayRefPlanPurchaseBonus")
            ->selectRaw("SUM((CASE WHEN created_at = CURDATE() AND `type` = 'ptc'  THEN amount END)) AS todayRefPTCBonus")
            ->selectRaw("SUM((CASE WHEN created_at = CURDATE()  THEN amount END)) AS todayRefBonus")
            ->get()->toArray())->collapse();



        $data['funding'] = collect(Fund::selectRaw('SUM(CASE WHEN status = 1 THEN amount END) AS totalAmountReceived')
            ->selectRaw('SUM(CASE WHEN status = 1 THEN charge END) AS totalChargeReceived')
            ->selectRaw('SUM((CASE WHEN created_at = CURDATE() AND status = 1 THEN amount END)) AS todayDeposit')
            ->selectRaw('SUM((CASE WHEN status = 1 AND created_at =  DATE_SUB(CURRENT_DATE() , INTERVAL DAYOFMONTH(CURRENT_DATE)-1 DAY) THEN amount END)) AS monthlyDepositAmount')
            ->get()->toArray())->collapse();

        $data['userRecord'] = collect(User::selectRaw('COUNT(id) AS totalUser')
            ->selectRaw('count(CASE WHEN status = 1  THEN id END) AS activeUser')
            ->selectRaw('SUM(balance) AS totalUserBalance')
            ->selectRaw('COUNT((CASE WHEN created_at = CURDATE()  THEN id END)) AS todayJoin')
            ->get()->makeHidden(['fullname', 'mobile'])->toArray())->collapse();


        $data['tickets'] = collect(Ticket::where('created_at', '>', Carbon::now()->subDays(30))
            ->selectRaw('count(CASE WHEN status = 3  THEN status END) AS closed')
            ->selectRaw('count(CASE WHEN status = 2  THEN status END) AS replied')
            ->selectRaw('count(CASE WHEN status = 1  THEN status END) AS answered')
            ->selectRaw('count(CASE WHEN status = 0  THEN status END) AS pending')
            ->get()->toArray())->collapse();


        //-- Pie Chart Data --


        //-- Line Chart Data --//
        $dailyInvest = $this->dayList();
        Fund::whereMonth('created_at', Carbon::now()->month)
            ->select(
                DB::raw('sum(amount) as totalAmount'),
                DB::raw('DATE_FORMAT(created_at,"Day %d") as date')
            )
            ->groupBy(DB::raw("DATE(created_at)"))
            ->get()->map(function ($item) use ($dailyInvest) {
                $dailyInvest->put($item['date'], round($item['totalAmount'], 2));
            });
        $statistics['deposit'] = $dailyInvest;



        $dailyAdsView = $this->dayList();
         PtcView::whereMonth('created_at', Carbon::now()->month)
            ->selectRaw('sum(amount) as totalAmount')
            ->selectRaw('DATE_FORMAT(created_at,"Day %d") as date')
            ->groupBy(DB::raw("DATE(created_at)"))
            ->get()->map(function ($item) use ($dailyAdsView) {
                $dailyAdsView->put($item['date'], round($item['totalAmount'], 2));
            });
        $statistics['adsView'] = $dailyAdsView;


        $dailyPlanPurchase = $this->dayList();
        Transaction::whereMonth('created_at', Carbon::now()->month)
            ->where('trx_type', '-')
            ->selectRaw('SUM((CASE WHEN remarks LIKE "Purchased%" THEN amount END)) AS totalAmount')
            ->selectRaw('DATE_FORMAT(created_at,"Day %d") as date')
            ->groupBy(DB::raw("DATE(created_at)"))
            ->get()->map(function ($item) use ($dailyPlanPurchase) {
                $dailyPlanPurchase->put($item['date'], round($item['totalAmount'], 2));
            });
       $statistics['planPurchase'] = $dailyPlanPurchase;



        $dailyPayout = $this->dayList();
        PayoutLog::whereMonth('created_at', Carbon::now()->month)
            ->select(
                DB::raw('sum(amount) as totalAmount'),
                DB::raw('DATE_FORMAT(created_at,"Day %d") as date')
            )
            ->where('status',2)
            ->groupBy(DB::raw("DATE(created_at)"))
            ->get()->map(function ($item) use ($dailyPayout) {
                $dailyPayout->put($item['date'], round($item['totalAmount'], 2));
            });
        $statistics['payout'] = $dailyPayout;

        $statistics['schedule'] = $this->dayList();

        $data['payout'] = collect(PayoutLog::selectRaw('COUNT(CASE WHEN status = 1  THEN id END) AS pending')
            ->selectRaw('SUM((CASE WHEN status = 2 AND created_at = CURDATE()  THEN amount END)) AS todayPayoutAmount')
            ->selectRaw('SUM((CASE WHEN status = 2 AND created_at =  DATE_SUB(CURRENT_DATE() , INTERVAL DAYOFMONTH(CURRENT_DATE)-1 DAY) THEN amount END)) AS monthlyPayoutAmount')
            ->selectRaw('SUM((CASE WHEN status = 2 AND created_at =  DATE_SUB(CURRENT_DATE() , INTERVAL DAYOFMONTH(CURRENT_DATE)-1 DAY) THEN charge END)) AS monthlyPayoutCharge')
            ->get()->toArray())->collapse();


        $data['latestUser'] = User::latest()->limit(5)->get();

        return view('admin.dashboard', $data, compact('statistics'));
    }


    public function dayList()
    {
        $totalDays = Carbon::now()->endOfMonth()->format('d');
        $daysByMonth = [];
        for ($i = 1; $i <= $totalDays; $i++) {
            array_push($daysByMonth, ['Day ' . sprintf("%02d", $i) => 0]);
        }

        return collect($daysByMonth)->collapse();
    }

    public function profile()
    {
        $admin = $this->user;
        return view('admin.profile', compact('admin'));
    }


    public function profileUpdate(Request $request)
    {
        $req = Purify::clean($request->except('_token', '_method'));
        $rules = [
            'name' => 'sometimes|required',
            'username' => 'sometimes|required|unique:admins,username,' . $this->user->id,
            'email' => 'sometimes|required|email|unique:admins,email,' . $this->user->id,
            'phone' => 'sometimes|required',
            'address' => 'sometimes|required',
            'image' => ['nullable', 'image', new FileTypeValidate(['jpeg', 'jpg', 'png'])]
        ];
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $user = $this->user;
        if ($request->hasFile('image')) {
            try {
                $old = $user->image ?: null;
                $user->image = $this->uploadImage($request->image, config('location.admin.path'), config('location.admin.size'), $old);
            } catch (\Exception $exp) {
                return back()->with('error', 'Image could not be uploaded.');
            }
        }
        $user->name = $req['name'];
        $user->username = $req['username'];
        $user->email = $req['email'];
        $user->phone = $req['phone'];
        $user->address = $req['address'];
        $user->save();

        return back()->with('success', 'Updated Successfully.');
    }


    public function password()
    {
        return view('admin.password');
    }

    public function passwordUpdate(Request $request)
    {
        $req = Purify::clean($request->all());

        $request->validate([
            'current_password' => 'required',
            'password' => 'required|min:5|confirmed',
        ]);

        $request = (object)$req;
        $user = $this->user;
        if (!Hash::check($request->current_password, $user->password)) {
            return back()->with('error', "Password didn't match");
        }
        $user->update([
            'password' => bcrypt($request->password)
        ]);
        return back()->with('success', 'Password has been Changed');
    }
}
