<?php

namespace App\Http\Controllers\Admin;

use App\Models\PtcView;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Models\ReferralBonus;
use App\Http\Controllers\Controller;

class LogController extends Controller
{
    public function transaction()
    {
        $transaction = Transaction::with('user')->orderBy('id', 'DESC')->paginate(config('basic.paginate'));
        return view('admin.transaction.index', compact('transaction'));
    }

    public function transactionSearch(Request $request)
    {
        $search = $request->all();
        $dateSearch = $request->datetrx;
        $date = preg_match("/^[0-9]{2,4}\-[0-9]{1,2}\-[0-9]{1,2}$/", $dateSearch);
        $transaction = Transaction::with('user')->orderBy('id', 'DESC')
            ->when(isset($search['transaction_id']), function ($query) use ($search) {
                return $query->where('trx_id', 'LIKE', "%{$search['transaction_id']}%");
            })
            ->when(isset($search['user_name']), function ($query) use ($search) {
                return $query->whereHas('user', function ($q) use ($search) {
                    $q->where('email', 'LIKE', "%{$search['user_name']}%")
                        ->orWhere('username', 'LIKE', "%{$search['user_name']}%");
                });
            })
            ->when(isset($search['remark']), function ($query) use ($search) {
                return $query->where('remarks', 'LIKE', "%{$search['remark']}%");
            })
            ->when($date == 1, function ($query) use ($dateSearch) {
                return $query->whereDate("created_at", $dateSearch);
            })
            ->paginate(config('basic.paginate'));
        $transaction =  $transaction->appends($search);
        return view('admin.transaction.index', compact('transaction'));
    }


    public function commissions()
    {
        $transactions =  ReferralBonus::latest()->with('user','bonusBy:id,firstname,lastname,username,image')->paginate(config('basic.paginate'));
        return view('admin.transaction.commission', compact('transactions'));
    }

    public function commissionsSearch(Request $request)
    {
        $search = $request->all();
        $dateSearch = $request->datetrx;
        $date = preg_match("/^[0-9]{2,4}\-[0-9]{1,2}\-[0-9]{1,2}$/", $dateSearch);
        $transactions = ReferralBonus::orderBy('id', 'DESC')
            ->when(isset($search['user_name']), function ($query) use ($search) {
                return $query->whereHas('user', function ($q) use ($search) {
                    $q->where('email', 'LIKE', "%{$search['user_name']}%")
                        ->orWhere('firstname', 'LIKE', "%{$search['user_name']}%")
                        ->orWhere('lastname', 'LIKE', "%{$search['user_name']}%")
                        ->orWhere('username', 'LIKE', "%{$search['user_name']}%");
                });
            })
            ->when($date == 1, function ($query) use ($dateSearch) {
                return $query->whereDate("created_at", $dateSearch);
            })
            ->with('user','bonusBy:id,firstname,lastname,username,image')->paginate(config('basic.paginate'));

        $transactions =  $transactions->appends($search);

        return view('admin.transaction.commission', compact('transactions'));
    }


    public function adViewLog()
    {
        $earnFromAd = PtcView::with('advertisement')->orderBy('id', 'DESC')->paginate(config('basic.paginate'));

        return view('admin.transaction.adsView', compact('earnFromAd'));
    }

    
    public function adViewLogSearch(Request $request)
    {
        $search = $request->all();

        $dateSearch = $request->datetrx;
        $date = preg_match("/^[0-9]{2,4}\-[0-9]{1,2}\-[0-9]{1,2}$/", $dateSearch);

        $earnFromAd = PtcView::with('advertisement')->orderBy('id', 'DESC')
                    ->when(isset($search['user_name']), function ($query) use ($search) {
                        return $query->whereHas('user', function ($q) use ($search) {
                            $q->where('email', 'LIKE', "%{$search['user_name']}%")
                                ->orWhere('firstname', 'LIKE', "%{$search['user_name']}%")
                                ->orWhere('lastname', 'LIKE', "%{$search['user_name']}%")
                                ->orWhere('username', 'LIKE', "%{$search['user_name']}%");
                        });
                    })
                    ->when(isset($search['ads_name']), function($query) use ($search) {
                        $query->whereHas('advertisement', function($qq) use ($search){
                                $qq->where('ads_name', 'LIKE', '%' . $search['ads_name'] . '%');
                            });
                    })
                    ->when(isset($search['ads_type']), function($query) use ($search) {
                        $query->whereHas('advertisement', function($qq) use ($search){
                                $qq->where('ads_type', $search['ads_type']);
                            });
                    })
                    ->when($date == 1, function ($query) use ($dateSearch) {
                        return $query->whereDate("created_at", $dateSearch);
                    })
                    ->paginate(config('basic.paginate'));

        $earnFromAd = $earnFromAd->appends($search);

        return view('admin.transaction.adsView', compact('earnFromAd'));
    }


}
