<?php

namespace App\Http\Controllers\User;
use App\Models\Ptc;
use App\Models\PtcView;
use App\Models\Configure;
use App\Http\Traits\Upload;
use App\Models\Transaction;
use Illuminate\Http\Request;
use Facades\App\Services\BasicService;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class PtcManageController extends Controller
{
    use Upload;

    public $theme, $user;

    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(function ($request, $next) {
            $this->user = auth()->user();
            return $next($request);
        });
        $this->theme = template();
    }


    public function allAdvertise()
    {
        $siteConfigure = Configure::first();
        $activeAds = Ptc::where('status',1)
                ->where('remaining','>',0)
                ->inRandomOrder()
                ->orderBy('id','DESC')
                ->withCount('todayPtcView')
                ->paginate(config('basic.paginate'));

        return view($this->theme . 'user.ptc.allAdvertise', compact('activeAds', 'siteConfigure'));
    }


    public function createAdvertise(Request $request)
    {
        $siteConfigure = Configure::first();
        return view($this->theme . 'user.ptc.createAdvertise', compact('siteConfigure'));
    }


    public function storeMyAdvertise(Request $request)
    {
        $siteConfigure = Configure::first();

        if ($siteConfigure->user_ads_status == 0) {
            abort(404);
        }

        $user = auth()->user();

        $rules = [
            'ads_name' => 'required|max:30|min:3',
            'ads_type' => 'required|in:1,2,3,4|integer',
            'ads_duration' => 'required|min:1|integer|max:10',
            'website_link' => 'nullable|url|required_without_all:banner_image,script,youtube',
            'script' => 'nullable|required_without_all:website_link,banner_image,youtube',
            'youtube' => 'nullable|required_without_all:website_link,banner_image,script',
            'banner_image' => 'nullable|mimes:jpeg,jpg,png,gif|required_without_all:website_link,script,youtube',
            'max_show_limit' => 'required|integer|min:1',
        ];
        $message = [
            'ads_name.required'   => 'Ads Name field is required',
            'ads_name.max'   => 'Ads Name field may not be greater than :max characters.',
            'ads_name.min'   => 'Ads Name field may not be less than :min characters.',
            'ads_type.required'   => 'Ads Type field is required',
            'ads_duration.required'   => 'Ads Duration field is required',
            'ads_duration.max'   => 'Ads Duration field may not be greater than :max seconds.',
            'ads_duration.min'   => 'Ads Duration field may not be less than :min seconds.',
            'website_link.required_without_all'   => 'The URL/Link field is required.',
            'script.required_without_all'   => 'The Code/Script field is required.',
            'youtube.required_without_all'   => 'The Youtube Embeded Link field is required.',
            'banner_image.required_without_all'   => 'The Picture/Banner field is required.',
            'max_show_limit.required'   => 'Maximum Show Limit field is required',
        ];

        $validate = Validator::make($request->all(), $rules, $message);

        if ($validate->fails()) {
            $validate->errors()->add('storeAdsError', 'storeAdsError');
            return back()->withInput()->withErrors($validate);
        }


        if ($request->ads_type == 1) {
            $adsPrice = @$siteConfigure->ads_setting->ad_price->url ?? 0;
            $userAmount = @$siteConfigure->ads_setting->amount_for_user->url ?? 0;
        } elseif($request->ads_type == 4) {
            $adsPrice = @$siteConfigure->ads_setting->ad_price->script ?? 0;
            $userAmount = @$siteConfigure->ads_setting->amount_for_user->script ?? 0;
        } elseif ($request->ads_type == 3) {
            $adsPrice = @$siteConfigure->ads_setting->ad_price->image ?? 0;
            $userAmount = @$siteConfigure->ads_setting->amount_for_user->image ?? 0;
        } elseif ($request->ads_type == 2) {
            $adsPrice = @$siteConfigure->ads_setting->ad_price->youtube ?? 0;
            $userAmount = @$siteConfigure->ads_setting->amount_for_user->youtube ?? 0;
        }

        $totalAddsPrice = $adsPrice * $request->max_show_limit;

        if ($user->balance < $totalAddsPrice) {
            return redirect()->route('user.addFund')->with('error', "Sorry! You don't have enough funds to create Advertisement.");
        }

        $user->balance -= $totalAddsPrice;
        $user->save();

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->charge = 0.00;
        $transaction->amount = $totalAddsPrice;
        $transaction->final_balance = $user->balance;
        $transaction->trx_type = '-';
        $transaction->remarks = 'Advertisement Created';
        $transaction->trx_id = strRandom();
        $transaction->save();

        $PTC = new Ptc();
        $PTC->user_id = $user->id;
        $PTC->ads_name = $request->ads_name;
        $PTC->ads_type = $request->ads_type;
        $PTC->user_amount = $userAmount;
        $PTC->ads_duration = $request->ads_duration;
        $PTC->max_show_limit = $request->max_show_limit;
        $PTC->remaining = $request->max_show_limit;
        $PTC->status = 2;

        if($request->ads_type == 1){
            $PTC->ads_body = $request->website_link;
        }elseif($request->ads_type == 3){
            if ($request->hasFile('banner_image')) {
                $PTC->ads_body = $this->uploadImage($request->banner_image, config('location.advertisement.path'), null, null);
            }
        }elseif($request->ads_type == 2){
            $PTC->ads_body = $request->youtube;
        }elseif($request->ads_type == 4){
            $PTC->ads_body = $request->script;
        }

        $PTC->save();

        return redirect()->route('user.my.advertise')->with('success', 'Advertisement Saved Successfully');
    }


    public function editMyAdvertise($id)
    {
        $myAdvertise = Ptc::where('user_id',$this->user->id)->findOrFail($id);
        return view($this->theme . 'user.ptc.editAdvertise', compact('myAdvertise'));
    }


    public function updateMyAdvertise(Request $request, $id)
    {
        $rules = [
            'ads_name' => 'required|max:30|min:3',
            'ads_duration' => 'required|min:1|integer|max:10',
            'website_link' => 'nullable|url',
            'script' => 'nullable',
            'youtube' => 'nullable',
            'banner_image' => 'nullable|mimes:jpeg,jpg,png,gif',
        ];
        $message = [
            'ads_name.required'   => 'Ads Name field is required',
            'ads_name.max'   => 'Ads Name field may not be greater than :max characters.',
            'ads_name.min'   => 'Ads Name field may not be less than :min characters.',
            'ads_duration.required'   => 'Ads Duration field is required',
            'ads_duration.max'   => 'Ads Duration field may not be greater than :max seconds.',
            'ads_duration.min'   => 'Ads Duration field may not be less than :min seconds.',
        ];

        $validate = Validator::make($request->all(), $rules, $message);

        if ($validate->fails()) {
            return back()->withInput()->withErrors($validate);
        }

        $PTC = Ptc::where('user_id',auth()->id())->findOrFail($id);
        $PTC->ads_name = $request->ads_name;
        $PTC->ads_type = $request->ads_type;
        $PTC->ads_duration = $request->ads_duration;
        $PTC->status = 2;

        if($request->ads_type == 1){
            $PTC->ads_body = $request->website_link;
        }elseif($request->ads_type == 3){
            if ($request->hasFile('banner_image')) {
                $PTC->ads_body = $this->uploadImage($request->banner_image, config('location.advertisement.path'), null, $PTC->ads_body);
            }
        }elseif($request->ads_type == 2){
            $PTC->ads_body = $request->youtube;
        }elseif($request->ads_type == 4){
            $PTC->ads_body = $request->script;
        }

        $PTC->save();

        return redirect()->route('user.my.advertise')->with('success', 'Advertisement Updated Successfully');
    }


    public function myAdvertise()
    {
        $siteConfigure = Configure::select('user_ads_status')->first();
        $myAdvertise = Ptc::where('user_id',$this->user->id)->orderBy('id','DESC')->paginate(config('basic.paginate'));

        return view($this->theme . 'user.ptc.myAdvertise', compact('myAdvertise', 'siteConfigure'));
    }


    public function searchMyAdvertise(Request $request)
    {
        $siteConfigure = Configure::select('user_ads_status')->first();

        $search = $request->all();

        $myAdvertise = Ptc::orderBy('id', 'DESC')->where('user_id', $this->user->id)
                ->when(isset($search['ads_name']), function ($query) use ($search) {
                    return $query->where('ads_name', 'LIKE', '%' . $search['ads_name'] . '%');
                })
                ->when(isset($search['ads_type']), function ($query) use ($search) {
                    return $query->where('ads_type', $search['ads_type']);
                })
                ->when(isset($search['status']), function ($query) use ($search) {
                    return $query->where('status', $search['status']);
                })
                ->paginate(config('basic.paginate'));

        $myAdvertise->appends($search);

        return view($this->theme . 'user.ptc.myAdvertise', compact('myAdvertise', 'siteConfigure'));
    }


    public function deactiveMyAdvertise($id)
    {
        $PTC = Ptc::where('user_id',$this->user->id)->where('status',1)->findOrFail($id);
        $PTC->status = 0;
        $PTC->save();
        return redirect()->back()->with('success', 'Advertisement Deactivated Successfully');
    }


    public function activeMyAdvertise($id)
    {
        $PTC = Ptc::where('user_id',$this->user->id)->where('status',0)->findOrFail($id);
        $PTC->status = 1;
        $PTC->save();
        return redirect()->back()->with('success', 'Advertisement Activated Successfully');
    }


    public function viewAdvertise($hashId)
    {
        $user = $this->user;

        if ($user->plan_id == 0 || !$user->plan_id) {
            return redirect()->back()->with('error', 'You have no Plan. Kindly purchase a plan first.');
        }

        if ($user->validity_date < now()) {
            return redirect()->back()->with('error', 'Your membership of plan has been expired. Kindly renew your plan');
        }

        $decrypted_ids = decrypt($hashId);
        $decryptedData  = explode('|', $decrypted_ids);

        if($decryptedData[1] != $this->user->id){
            abort(404);
        }

        $ptcAdView = Ptc::where('id',$decryptedData[0])->where('remaining','>',0)->where('status',1)->firstOrFail();
        if ($user->id == $ptcAdView->user_id) {
            return redirect()->back()->with('error', "Sorry! You are unable to view your own advertisement");
        }

        $todayViewAdsCount = PtcView::where('user_id',$user->id)->whereDate('ad_view_date', now())->count();
        if($todayViewAdsCount >= $user->daily_ad_limit){
            return redirect()->back()->with('error', "Sorry! You have exceeded the daily advertisement view limit");
        }

        $todaySpecificAdView = PtcView::where('user_id',$user->id)->where('ptc_id',$ptcAdView->id)->whereDate('ad_view_date', now())->first();
        if ($todaySpecificAdView) {
            return redirect()->back()->with('error', "Sorry! You cannot see this advertisement before 24 hour");
        }

        $number1 = rand(0,9);
        $number2 = rand(0,9);

        return view($this->theme . 'user.ptc.viewAdvertise', compact('ptcAdView', 'number1', 'number2'));
    }


    public function submitViewAdvertise(Request $request, $hashId)
    {
        $rules = [
            'first_captcha_number'=>'required|integer',
            'second_captcha_number'=>'required|integer',
            'sum_captcha_numbers'=>'required|integer',
        ];
        $message = [
            'first_captcha_number.required'   => 'First captcha number field is required',
            'first_captcha_number.integer'   => 'First captcha number field must be a integer value',
            'second_captcha_number.required'   => 'First captcha number field is required',
            'second_captcha_number.integer'   => 'First captcha number field must be a integer value',
        ];

        $validate = Validator::make($request->all(), $rules, $message);

        if ($validate->fails()) {
            return back()->withInput()->withErrors($validate);
        }

        $numberOne = $request->first_captcha_number;
        $numberTwo = $request->second_captcha_number;
        $summation = $numberOne + $numberTwo;
        if ($request->sum_captcha_numbers != $summation) {
            return redirect()->back()->with('error', 'Incorrect Calculation, Please try again');
        }

        $currentUser = $this->user;
        $siteConfigure = Configure::first();

        if ($currentUser->plan_id == 0 || !$currentUser->plan_id) {
            return redirect()->back()->with('error', 'You have no Plan. Kindly purchase a plan first.');
        }

        if ($currentUser->validity_date < now()) {
            return redirect()->back()->with('error', 'Your membership of plan has been expired. Kindly renew your plan');
        }

        $decrypted_ids = decrypt($hashId);
        $decryptedData  = explode('|', $decrypted_ids);

        if($decryptedData[1] != $this->user->id){
            abort(404);
        }

        $ptcAdView = Ptc::where('id',$decryptedData[0])->where('remaining','>',0)->where('status',1)->firstOrFail();
        if ($currentUser->id == $ptcAdView->user_id) {
            return redirect()->back()->with('error', "Sorry! You are unable to view your own advertisement");
        }

        $todayViewAdsCount = PtcView::where('user_id',$currentUser->id)->whereDate('ad_view_date', now())->count();
        if($todayViewAdsCount >= $currentUser->daily_ad_limit){
            return redirect()->back()->with('error', "Sorry! You have exceeded the daily advertisement view limit");
        }

        $todaySpecificAdView = PtcView::where('user_id',$currentUser->id)->where('ptc_id',$ptcAdView->id)->whereDate('ad_view_date', now())->first();
        if ($todaySpecificAdView) {
            return redirect()->back()->with('error', "Sorry! You cannot see this advertisement before 24 hour");
        }


        $ptcAdView->increment('shown');
        $ptcAdView->decrement('remaining');
        $ptcAdView->save();

        $currentUser->balance += $ptcAdView->user_amount;
        $currentUser->save();

        $transaction_id = strRandom();
        $remark = "Earned from Advertisement View";
        BasicService::makeTransaction($currentUser, getAmount($ptcAdView->user_amount), 0, '+', $transaction_id, $remark);

        $adView = new PtcView();
        $adView->user_id = $currentUser->id;
        $adView->ptc_id = $ptcAdView->id;
        $adView->ad_view_date = now();
        $adView->amount = $ptcAdView->user_amount;
        $adView->save();

        if ($siteConfigure->ptc_view_commission == 1) {
            BasicService::setBonus($currentUser, getAmount($ptcAdView->user_amount), $type = 'ptc');
        }

        return redirect()->route('user.all.advertise')->with('success', 'Advertisement Viewed Successfully');
    }


    public function totalClickEarnings()
    {
        $earnFromAd = PtcView::with('advertisement')->where('user_id', $this->user->id)->orderBy('id', 'DESC')->paginate(config('basic.paginate'));

        return view($this->theme . 'user.ptc.earningFromClicks', compact('earnFromAd'));
    }


    public function searchClickEarnings(Request $request)
    {
        $search = $request->all();

        $dateSearch = $request->date_time;
        $date = preg_match("/^[0-9]{2,4}\-[0-9]{1,2}\-[0-9]{1,2}$/", $dateSearch);

        $earnFromAd = PtcView::with('advertisement')->where('user_id', $this->user->id)->orderBy('id', 'DESC')
                    ->when(isset($search['ads_name']), function($query) use ($search) {
                        $query->whereHas('advertisement', function($qq) use ($search){
                                $qq->where('ads_name', 'LIKE', '%' . $search['ads_name'] . '%');
                            });
                    })
                    ->when(isset($search['ads_type']), function($query) use ($search) {
                        $query->whereHas('advertisement', function($qq) use ($search){
                                $qq->where('ads_type', $search['ads_type']);
                            });
                    })
                    ->when($date == 1, function ($query) use ($dateSearch) {
                        return $query->whereDate("created_at", $dateSearch);
                    })
                    ->paginate(config('basic.paginate'));

        $earnFromAd = $earnFromAd->appends($search);

        return view($this->theme . 'user.ptc.earningFromClicks', compact('earnFromAd'));
    }


}
