<?php

namespace App\Providers;


use App\Models\Fund;
use App\Models\Ticket;
use App\Models\Gateway;
use App\Models\PtcView;
use App\Models\Language;
use App\Models\Referral;
use App\Models\Template;
use App\Models\PayoutLog;
use App\Models\ContentDetails;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\View;
use Illuminate\Support\ServiceProvider;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {

    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        $data['basic'] = (object) config('basic');
        $data['theme'] = template();
        $data['themeTrue'] = template(true);

        View::share($data);

        try {
            DB::connection()->getPdo();

            view()->composer(['admin.ticket.nav', 'dashboard'], function ($view) {
                $view->with('pending', Ticket::whereIn('status', [0, 2])->latest()->with('user')->limit(10)->with('lastReply')->get());
            });

            view()->composer([
                $data['theme'] . 'partials.footer',
            ] , function ($view) {
                $allLanguages = \App\Models\Language::orderBy('name')->where('is_active', 1)->get();
                $view->with('allLanguage', $allLanguages);

                $templateSection = ['contact-us'];
                $view->with('contactUs', Template::templateMedia()->whereIn('section_name', $templateSection)->get()->groupBy('section_name'));

                $templateNewsletter = ['news-letter'];
                $view->with('newsLetter', Template::templateMedia()->whereIn('section_name', $templateNewsletter)->get()->groupBy('section_name'));

                $contentSection = ['pages','social'];
                $view->with('contentDetails', ContentDetails::select('id', 'content_id', 'description')
                    ->whereHas('content', function ($query) use ($contentSection) {
                        return $query->whereIn('name', $contentSection);
                    })
                    ->with(['content:id,name',
                        'content.contentMedia' => function ($q) {
                            $q->select(['content_id', 'description']);
                        }])
                    ->get()->groupBy('content.name'));
            });


            view()->composer($data['theme'] . 'user.ptc.allAdvertise', function ($view) {
                $view->with('todayViewAdsCount', PtcView::where('user_id',auth()->user()->id)->whereDate('ad_view_date', now())->count());
            });

            view()->composer($data['theme'] . 'sections.referral-deposit', function ($view) {
                $view->with('referralLevelDeposit', Referral::where('commission_type','deposit')->orderBy('level')->get());
            });

            view()->composer($data['theme'] . 'sections.referral-planPurchase', function ($view) {
                $view->with('referralLevelPlanPurchase', Referral::where('commission_type','invest')->orderBy('level')->get());
            });

            view()->composer($data['theme'] . 'sections.referral-adsView', function ($view) {
                $view->with('referralLevelAdsView', Referral::where('commission_type','ptc')->orderBy('level')->get());
            });


            view()->composer($data['theme'] . 'sections.deposit-withdraw', function ($view) {
                $view->with('deposits', Fund::latest()->where('status', 1)->limit(5)->with('user','gateway')->get());
                $view->with('withdraws', PayoutLog::latest()->where('status', 2)->limit(5)->with('user','method')->get());
            });

        } catch (\Exception $e) {
//            die("Could not connect to the database.  Please check your configuration according to documentation" );
        }

    }

}
