<?php

namespace App\Services;

use App\Http\Traits\Notify;
use App\Models\Transaction;
use Carbon\Carbon;
use Illuminate\Support\Facades\Log;
use Image;

class BasicService
{
    use Notify;

    public function validateImage(object $getImage, string $path)
    {
        if ($getImage->getClientOriginalExtension() == 'jpg' or $getImage->getClientOriginalName() == 'jpeg' or $getImage->getClientOriginalName() == 'png') {
            $image = uniqid() . '.' . $getImage->getClientOriginalExtension();
        } else {
            $image = uniqid() . '.jpg';
        }
        Image::make($getImage->getRealPath())->resize(300, 250)->save($path . $image);
        return $image;
    }

    public function validateDate(string $date)
    {
        if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{2,4}$/", $date)) {
            return true;
        } else {
            return false;
        }
    }

    public function validateKeyword(string $search, string $keyword)
    {
        return preg_match('~' . preg_quote($search, '~') . '~i', $keyword);
    }

    public function cryptoQR($wallet, $amount, $crypto = null)
    {

        $varb = $wallet . "?amount=" . $amount;
        return "https://chart.googleapis.com/chart?chs=300x300&cht=qr&chl=$varb&choe=UTF-8";
    }

    public function preparePaymentUpgradation($order)
    {
        $basic = (object)config('basic');
        $gateway = $order->gateway;


        if ($order->status == 0) {
            $order['status'] = 1;
            $order->update();

            $user = $order->user;
            $user->balance += $order->amount;
            $user->save();

            $this->makeTransaction($user, getAmount($order->amount), getAmount($order->charge), '+', $order->transaction, 'Payment Via ' . $gateway->name);

            if ($basic->deposit_commission == 1) {
                $this->setBonus($user, getAmount($order->amount), $type = 'deposit');
            }

            try {

                $msg = [
                    'username' => $user->username,
                    'amount' => getAmount($order->amount),
                    'currency' => $basic->currency,
                    'gateway' => $gateway->name
                ];
                $action = [
                    "link" => route('admin.user.fundLog', $user->id),
                    "icon" => "fa fa-money-bill-alt text-white"
                ];
                $this->adminPushNotification('ADD_FUND_PAYMENT_COMPLETE_TO_ADMIN', $msg, $action);


                $msgUser = [
                    'amount' => getAmount($order->amount),
                    'currency' => $basic->currency,
                    'gateway' => $gateway->name
                ];
                $actionUser = [
                    "link" => route('user.fund-history'),
                    "icon" => "fa fa-money-bill-alt text-white"
                ];
                $this->userPushNotification($user, 'ADD_FUND_PAYMENT_COMPLETE_TO_USER', $msgUser, $actionUser);


                $this->sendMailSms($user, 'ADD_FUND_PAYMENT_COMPLETE', [
                    'gateway_name' => $gateway->name,
                    'amount' => getAmount($order->amount),
                    'charge' => getAmount($order->charge),
                    'currency' => $basic->currency,
                    'transaction' => $order->transaction,
                    'remaining_balance' => getAmount($user->balance)
                ]);

            } catch (\Exception $e) {

            }
        }

        session()->forget('amount');

    }


    public function setBonus($user, $amount, $commissionType = '')
    {
        $basic = (object)config('basic');
        $userId = $user->id;
        $i = 1;

        $level = \App\Models\Referral::where('commission_type', $commissionType)->count();

        while ($userId != "" || $userId != "0" || $i < $level) {
            $me = \App\Models\User::with('referral')->find($userId);
            $refer = $me->referral;
            if (!$refer) {
                break;
            }

            if ($commissionType == 'invest' || $commissionType == 'ptc') {
                if ($i == 1) {
                    $plan = $me->plan;
                }
                if (!$plan) {
                    $userId = $refer->id;
                    $i++;
                    continue;
                }

                if ($i > $plan->referral_level) {
                    $userId = $refer->id;
                    $i++;
                    continue;
                }
            }

            $commission = \App\Models\Referral::where('commission_type', $commissionType)->where('level', $i)->first();
            if (!$commission) {
                break;
            }
            $com = ($amount * $commission->percent) / 100;
            $new_bal = getAmount($refer->balance + $com);
            $refer->balance = $new_bal;
            $refer->save();

            $trx = strRandom();

            // $remarks = ' level ' . $i . ' Referral bonus From ' . $user->username;
            if ($commission->commission_type == "invest") {
                $remarks = 'Level ' . $i . ' Purchased Plan Referral Bonus From ' . $user->username;
            } elseif ($commission->commission_type == "deposit") {
                $remarks = 'Level ' . $i . ' Add Fund Referral Bonus From ' . $user->username;
            } elseif ($commission->commission_type == "ptc") {
                $remarks = 'Level ' . $i . ' Ad View Referral Bonus From ' . $user->username;
            }

            $this->makeTransaction($refer, $com, 0, '+R', $trx, $remarks);

            $bonus = new \App\Models\ReferralBonus();
            $bonus->from_user_id = $refer->id;
            $bonus->to_user_id = $user->id;
            $bonus->level = $i;
            $bonus->amount = getAmount($com);
            $bonus->main_balance = $new_bal;
            $bonus->transaction = $trx;
            $bonus->type = $commissionType;
            $bonus->remarks = $remarks;
            $bonus->save();


            $this->sendMailSms($refer, $type = 'REFFERAL_BONUS_COMMISSION', [
                'transaction' => $trx,
                'amount' => getAmount($com),
                'currency' => $basic->currency,
                'referral_from' => $user->username,
                'current_balance' => getAmount($refer->balance),
                'level' => $i
            ]);

            try {
                $msg = [
                    'referral_from' => $user->username,
                    'amount' => getAmount($com),
                    'currency' => $basic->currency,
                    'level' => $i
                ];
                $action = [
                    "link" => route('user.referral.bonus'),
                    "icon" => "fa fa-money-bill-alt"
                ];
                $this->userPushNotification($refer, 'REFFERAL_BONUS_COMMISSION', $msg, $action);
            } catch (\Exception $e) {

            }

            $userId = $refer->id;
            $i++;
        }
        return 0;

    }


    /**
     * @param $user
     * @param $amount
     * @param $charge
     * @param $trx_type
     * @param $balance_type
     * @param $trx_id
     * @param $remarks
     */
    public function makeTransaction($user, $amount, $charge, $trx_type = null, $trx_id, $remarks = null): void
    {
        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = getAmount($amount);
        $transaction->charge = $charge;
        $transaction->trx_type = $trx_type;
        $transaction->final_balance = $user->balance;
        $transaction->trx_id = $trx_id;
        $transaction->remarks = $remarks;
        $transaction->save();
    }


}
