@extends('admin.layouts.app')
@section('title')
    @lang('Add Advertisement')
@endsection

@section('content')

<div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">
    <div class="card-body">
        <div class="media mb-4 justify-content-end">
            <a href="{{route('admin.manage.advertisement')}}" class="btn btn-sm btn-primary mr-2">
                <span><i class="fas fa-arrow-left"></i> @lang('Back')</span>
            </a>
        </div>

        <div class="mt-2">
            <form method="post" action="{{ route('admin.advertisement.store') }}" class="mt-4" enctype="multipart/form-data">
                @csrf
                <div class="row">
                    <div class="col-sm-12 col-md-6 mb-3">
                        <label for="ads_name">@lang('Advertise Name') <span class="text-danger">*</span></label>
                        <input type="text" name="ads_name" class="form-control" value="{{ old('ads_name') }}" required placeholder="@lang('Enter Advertise Name')" id="ads_name"/>
                        @error('ads_name')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-6 mb-3">
                        <label for="user_amount">@lang('User Amount') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="number" name="user_amount" class="form-control" value="{{ old('user_amount') }}" required placeholder="@lang('Enter User Amount')" step="any">
                            <span class="input-group-text border-0">@lang($basic->currency)</span>
                        </div>
                        @error('user_amount')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>


                    <div class="col-sm-6 col-md-4 mb-3">
                        <label for="ads_duration">@lang('Advertisement Duration') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="text" name="ads_duration" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('ads_duration') }}" required placeholder="@lang('Enter advertisement duration')">
                            <span class="input-group-text gradientBg border-0">@lang('Seconds')</span>
                        </div>
                        @error('ads_duration')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-6 col-md-4 mb-3">
                        <label for="max_show_limit">@lang('Maximum Show Limit') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="text" name="max_show_limit" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('max_show_limit') }}" required placeholder="@lang('Enter maximum show limit')">
                            <span class="input-group-text gradientBg border-0">@lang('Times')</span>
                        </div>
                        @error('max_show_limit')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-4 mb-3">
                        <label>@lang('Status') <span class="text-danger">*</span></label>
                        <div class="custom-switch-btn">
                            <input type='hidden' value='1' name='status'>
                            <input type="checkbox" name="status" class="custom-switch-checkbox" id="status" value="2">
                            <label class="custom-switch-checkbox-label" for="status">
                                <span class="custom-switch-checkbox-inner"></span>
                                <span class="custom-switch-checkbox-switch"></span>
                            </label>
                        </div>
                        @error('status')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-4 mb-3">
                        <label for="ads_type">@lang('Advertisement Type') <span class="text-danger">*</span></label>
                        <select name="ads_type" required class="form-control" id="ads_type">
                            <option value="1" {{ old('ads_type') == 1 ? 'selected' : '' }}>@lang('URL/Link')</option>
                            <option value="4" {{ old('ads_type') == 4 ? 'selected' : '' }}>@lang('Code/Script')</option>
                            <option value="3" {{ old('ads_type') == 3 ? 'selected' : '' }}>@lang('Picture/Banner')</option>
                            <option value="2" {{ old('ads_type') == 2 ? 'selected' : '' }}>@lang('Youtube Embeded Link')</option>
                        </select>
                        @error('ads_type')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-8 mb-3" id="websiteLink">
                        <label>@lang('URL/Link') <span class="text-danger">*</span></label>
                        <input type="url" class="form-control" value="{{ old('website_link') }}" name="website_link" placeholder="@lang('http://example.com')"/>
                        @error('website_link')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-8 mb-3" id="youtube">
                        <label>@lang('Youtube Embeded Link') <span class="text-danger">*</span></label>
                        <input type="text" class="form-control" name="youtube" value="{{ old('youtube') }}" placeholder="@lang('Enter youtube embed link')"/>
                        @error('youtube')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-4 mb-3" id="bannerImage">
                        <div class="form-group">
                            <label>@lang('Picture/Banner') <span class="text-danger">*</span></label>
                            <div class="image-input ">
                                <label for="image-upload" id="image-label"><i class="fas fa-upload"></i></label>
                                <input type="file" name="banner_image" placeholder="@lang('Choose Picture/Banner')" id="image" accept="image/*">
                                <img id="image_preview_container" class="preview-image"
                                    src="{{ getFile(config('location.advertisement.path')) }}"
                                    alt="@lang('preview image')">
                            </div>
                            @error('image')
                                <span class="text-danger">{{ $message }}</span>
                            @enderror
                        </div>
                    </div>

                    <div class="col-sm-12 col-md-8 mb-3" id="script">
                        <label>@lang('Script/Code') <span class="text-danger">*</span></label>
                        <textarea
                            class="form-control"
                            name="script"
                            cols="30"
                            rows="3"
                            placeholder="@lang('Enter Script/Code')"
                        ></textarea>
                        @error('script')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                </div>

                <button type="submit" class="btn waves-effect waves-light btn-rounded btn-primary btn-block mt-3">
                    @lang('Save')
                </button>
            </form>
        </div>
    </div>
</div>

@endsection



@push('css-lib')
    <link rel="stylesheet" href="{{asset($themeTrue.'css/bootstrap-fileinput.css')}}">
@endpush

@push('extra-js')
    <script src="{{asset($themeTrue.'js/bootstrap-fileinput.js')}}"></script>
@endpush

@push('js')
    <script>
        (function($){
            "use strict";

            var price = 0;

            $('#ads_type').on('change',function(){
                var adsType = $(this).val();
                if (adsType == 1) {
                    $("#websiteLink").removeClass('d-none');
                    $("#bannerImage").addClass('d-none');
                    $("#script").addClass('d-none');
                    $("#youtube").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->url }}
                } else if (adsType == 2) {
                    $("#youtube").removeClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#script").addClass('d-none');
                    $("#bannerImage").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->youtube ?? 0}}
                } else if(adsType == 3) {
                    $("#script").addClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#bannerImage").removeClass('d-none');
                    $("#youtube").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->image }}
                } else {
                    $("#bannerImage").addClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#youtube").addClass('d-none');
                    $("#script").removeClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->script }}
                }

                $('.price-per-ad').text(price);

                $('[name=max_show_limit]').trigger('input');

            }).on('change',);


            $('[name=max_show_limit]').on('input', function () {
                var maxShow = $(this).val();
                var totalPrice = price * maxShow;
                $('.total-price').text(totalPrice);
            });


            $('#image').on('change',function () {
                let reader = new FileReader();
                reader.onload = (e) => {
                    $('#image_preview_container').attr('src', e.target.result);
                }
                reader.readAsDataURL(this.files[0]);
            });

        })(jQuery);


    </script>
@endpush
