@extends('admin.layouts.app')
@section('title')
    @lang('Edit Advertisement')
@endsection

@section('content')

<div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">
    <div class="card-body">
        <div class="media mb-4 justify-content-end">
            <a href="{{route('admin.manage.advertisement')}}" class="btn btn-sm btn-primary mr-2">
                <span><i class="fas fa-arrow-left"></i> @lang('Back')</span>
            </a>
        </div>

        <div class="mt-2">
            <form method="post" action="{{ route('admin.update.advertisement', $ad_data->id) }}" class="mt-4" enctype="multipart/form-data">
                @csrf
                @method('put')
                <div class="row">
                    <div class="col-sm-12 col-md-6 mb-4">
                        <label for="ads_name">@lang('Advertise Name') <span class="text-danger">*</span></label>
                        <input type="text" name="ads_name" class="form-control" value="{{ old('ads_name', $ad_data->ads_name) }}" required placeholder="@lang('Enter Advertise Name')" id="ads_name"/>
                        @error('ads_name')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-6 mb-4">
                        <label for="user_amount">@lang('User Amount') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="number" name="user_amount" class="form-control" value="{{ old('user_amount', $ad_data->user_amount) }}" required placeholder="@lang('Enter User Amount')" step="any">
                            <span class="input-group-text border-0">@lang($basic->currency)</span>
                        </div>
                        @error('user_amount')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>


                    <div class="col-sm-6 col-md-4 mb-4">
                        <label for="ads_duration">@lang('Advertisement Duration') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="text" name="ads_duration" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('ads_duration', $ad_data->ads_duration) }}" required placeholder="@lang('Enter advertisement duration')">
                            <span class="input-group-text gradientBg border-0">@lang('Seconds')</span>
                        </div>
                        @error('ads_duration')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-6 col-md-4 mb-4">
                        <label for="max_show_limit">@lang('Maximum Show Limit') <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <input type="text" name="max_show_limit" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('max_show_limit', $ad_data->max_show_limit) }}" required placeholder="@lang('Enter maximum show limit')">
                            <span class="input-group-text gradientBg border-0">@lang('Times')</span>
                        </div>
                        @error('max_show_limit')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-4 mb-4">
                        <label>@lang('Status') <span class="text-danger">*</span></label>
                        <select name="status" required class="form-control" id="status">
                            <option value="0" {{ old('status') == 0 ? 'selected' : '' }}>@lang('Deactive')</option>
                            <option value="1" {{ old('status', $ad_data->status) == 1 ? 'selected' : '' }}>@lang('Approve')</option>
                            <option value="2" {{ old('status', $ad_data->status) == 2 ? 'selected' : '' }}>@lang('Pending')</option>
                            <option value="3" {{ old('status', $ad_data->status) == 3 ? 'selected' : '' }}>@lang('Reject')</option>
                        </select>
                        @error('status')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    <div class="col-sm-12 col-md-4 mb-4">
                        <label for="ads_type">@lang('Advertisement Type') <span class="text-danger">*</span></label>
                        <input type="hidden" name="ads_type" value="{{ old('ads_type', $ad_data->ads_type)}}">
                            <div class="">
                                @if ($ad_data->ads_type == 1)
                                    <span class="badge badge-pill badge-primary">@lang('URL/Link')</span>
                                @elseif ($ad_data->ads_type == 4)
                                    <span class="badge badge-pill badge-info">@lang('Code/Script')</span>
                                @elseif ($ad_data->ads_type == 3)
                                    <span class="badge badge-pill badge-secondary">@lang('Picture/Banner')</span>
                                @elseif ($ad_data->ads_type == 2)
                                    <span class="badge badge-pill badge-danger">@lang('Youtube Embeded Link')</span>
                                @endif
                            </div>
                        @error('ads_type')
                            <span class="text-danger">@lang($message)</span>
                        @enderror
                    </div>

                    @if ($ad_data->ads_type == 1)
                        <div class="col-sm-12 col-md-8 mb-4" id="websiteLink">
                            <label>@lang('URL/Link') <span class="text-danger">*</span></label>
                            <input type="url" class="form-control" value="{{ old('website_link', $ad_data->ads_body) }}" name="website_link" placeholder="@lang('http://example.com')" required/>
                            @error('website_link')
                                <span class="text-danger">@lang($message)</span>
                            @enderror
                        </div>
                    @elseif ($ad_data->ads_type == 4)
                        <div class="col-sm-12 col-md-8 mb-4" id="script">
                            <label>@lang('Script/Code') <span class="text-danger">*</span></label>
                            <textarea
                                class="form-control"
                                name="script"
                                cols="30"
                                rows="3"
                                placeholder="@lang('Enter Script/Code')"
                                required
                            >{{$ad_data->ads_body}}</textarea>
                            @error('script')
                                <span class="text-danger">@lang($message)</span>
                            @enderror
                        </div>
                    @elseif ($ad_data->ads_type == 3)
                        <div class="col-sm-12 col-md-4 mb-4" id="bannerImage">
                            <div class="form-group">
                                <label>@lang('Picture/Banner') <span class="text-danger">*</span></label>
                                <div class="image-input ">
                                    <label for="image-upload" id="image-label"><i class="fas fa-upload"></i></label>
                                    <input type="file" name="banner_image" placeholder="@lang('Choose Picture/Banner')" id="image" accept="image/*">
                                    <img id="image_preview_container" class="preview-image"
                                        src="{{ getFile(config('location.advertisement.path')) }}"
                                        alt="@lang('preview image')">
                                </div>
                                @error('image')
                                    <span class="text-danger">{{ $message }}</span>
                                @enderror
                            </div>
                        </div>
                        <div class="col-md-4 mb-4">
                            <label>@lang('Current Existing Picture/Banner :')</label>
                            <img class="w-100" src="{{ getFile(config('location.advertisement.path').$ad_data->ads_body) }}">
                        </div>
                    @elseif ($ad_data->ads_type == 2)
                        <div class="col-sm-12 col-md-8 mb-4" id="youtube">
                            <label>@lang('Youtube Embeded Link') <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" name="youtube" value="{{ old('youtube', $ad_data->ads_body) }}" placeholder="@lang('Enter youtube embed link')" required/>
                            @error('youtube')
                                <span class="text-danger">@lang($message)</span>
                            @enderror
                        </div>
                    @endif
                </div>

                <button type="submit" class="btn waves-effect waves-light btn-rounded btn-primary btn-block mt-3">
                    @lang('Save')
                </button>

            </form>

        </div>
    </div>
</div>

@endsection

@push('js')
    <script>
        (function($){
            "use strict";

            $('#image').on('change',function () {
                let reader = new FileReader();
                reader.onload = (e) => {
                    $('#image_preview_container').attr('src', e.target.result);
                }
                reader.readAsDataURL(this.files[0]);
            });

        })(jQuery);

        $('select').select2({
            selectOnClose: true,
            width: '100%'
        });
    </script>

    @if ($errors->any())
        @php
            $collection = collect($errors->all());
            $errors = $collection->unique();
        @endphp
        <script>
            "use strict";
            @foreach ($errors as $error)
            Notiflix.Notify.Failure("{{trans($error)}}");
            @endforeach
        </script>
    @endif

@endpush
