@extends('admin.layouts.app')
@section('title')
    @lang('Advertisement List')
@endsection

@section('content')
    <div class="page-header card card-primary m-0 m-md-4 my-4 m-md-0 p-5 shadow">
        <form action="{{ route('admin.search.advertisement') }}" method="get">
            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <input type="text" name="ads_name" value="{{old('ads_name',@request()->ads_name)}}" class="form-control" placeholder="@lang('Search by Ads Name')">
                    </div>
                </div>
                <div class="col-md-3">
                    <select name="ads_type" class="form-control" aria-label="Default select example">
                        <option value="">@lang('Ads Type')</option>
                        <option value="1"
                                @if(@request()->ads_type == '1') selected @endif>@lang('URL/Link')</option>
                        <option value="2"
                                @if(@request()->ads_type == '2') selected @endif>@lang('Youtube Embeded Link')</option>
                        <option value="3"
                                @if(@request()->ads_type == '3') selected @endif>@lang('Picture/Banner')</option>
                        <option value="4"
                                @if(@request()->ads_type == '4') selected @endif>@lang('Code/Script')</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <select name="status" class="form-control" aria-label="Default select example">
                        <option value="">@lang('All Ads')</option>
                        <option value="0"
                                @if(@request()->status == '0') selected @endif>@lang('Deactive Ads')</option>
                        <option value="1"
                                @if(@request()->status == '1') selected @endif>@lang('Active Ads')</option>
                        <option value="2"
                                @if(@request()->status == '2') selected @endif>@lang('Pending Ads')</option>
                        <option value="3"
                                @if(@request()->status == '3') selected @endif>@lang('Rejected Ads')</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <div class="form-group">
                        <button type="submit" class="btn waves-effect waves-light btn-primary"><i class="fas fa-search"></i> @lang('Search')</button>
                    </div>
                </div>
            </div>
        </form>
    </div>


    <div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">
        <div class="card-body">
            <div class="media mb-4 float-right">
                <a href="{{ route('admin.create.advertisement')}}" class="btn btn-sm btn-primary mr-2">
                    <span><i class="fa fa-plus-circle"></i> @lang('Add New Advetisement')</span>
                </a>
            </div>

            <div class="table-responsive">
                <table class="categories-show-table table table-hover table-striped table-bordered">
                    <thead class="thead-dark">
                        <tr>
                            <th scope="col">@lang('Ads Name')</th>
                            <th scope="col">@lang('Submitted By')</th>
                            <th scope="col">@lang('Ads Type')</th>
                            <th scope="col">@lang('Duration')</th>
                            <th scope="col">@lang('Amount')</th>
                            <th scope="col">@lang('Max View')</th>
                            <th scope="col">@lang('Viewed')</th>
                            <th scope="col">@lang('Remaining')</th>
                            <th scope="col">@lang('Status')</th>
                            <th scope="col">@lang('Action')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($allAds as $key => $item)
                            <tr>
                                <td data-label="@lang('Ads Name')">@lang(Illuminate\Support\Str::limit(($item->ads_name),30))</td>
                                <td data-label="@lang('Submitted By')">
                                    @if($item->user)
                                        <a href="{{route('admin.user-edit', optional($item->user)->id)}}" target="_blank" class="userList">
                                            <div class="d-flex no-block align-items-center">
                                                <div class="mr-2">
                                                    <img src="{{getFile(config('location.user.path').optional($item->user)->image) }}" alt="@lang('user image')" class="rounded-circle" width="45" height="45">
                                                    @if(optional($item->user)->last_seen == 'online')
                                                        <span class="{{optional($item->user)->last_seen == 'online' ? 'onlineOffline' : '' }}"></span>
                                                    @endif
                                                </div>
                                                <div class="">
                                                    <h5 class="text-dark mb-0 font-16 font-weight-medium">@lang(optional($item->user)->firstname) @lang(optional($item->user)->lastname)</h5>
                                                    <span class="text-muted font-14"><span>@</span>@lang(optional($item->user)->username)</span>
                                                </div>
                                            </div>
                                        </a>
                                    @else
                                        @lang('Admin')
                                    @endif
                                </td>
                                <td data-label="@lang('Ads Type')">
                                    <button class="previewAd btn btn-transparent">
                                        @if($item->ads_type == 1)
                                            <span class="badge badge-pill badge-primary adCategory"
                                                data-adlink="{{ $item->ads_body }}"
                                                data-adtype="{{ $item->ads_type }}"
                                            >
                                                @lang('URL/Link')
                                            </span>
                                        @elseif($item->ads_type == 2)
                                            <span class="badge badge-pill badge-danger adCategory"
                                                data-adlink="{{ $item->ads_body }}"
                                                data-adtype="{{ $item->ads_type }}"
                                            >
                                                @lang('Youtube Embeded Link')
                                            </span>
                                        @elseif($item->ads_type == 3)
                                            <span class="badge badge-pill badge-success adCategory"
                                                data-adlink="{{ $item->ads_body }}"
                                                data-adtype="{{ $item->ads_type }}"
                                            >
                                                @lang('Picture/Banner')
                                            </span>
                                        @elseif($item->ads_type == 4)
                                            <span class="badge badge-pill badge-dark adCategory"
                                                data-adlink="{{ $item->ads_body }}"
                                                data-adtype="{{ $item->ads_type }}"
                                            >
                                                @lang('Code/Script')
                                            </span>
                                        @endif
                                    </button>
                                </td>
                                <td data-label="@lang('Duration')">@lang($item->ads_duration) @lang('Second')</td>
                                <td data-label="@lang('Amount')">@lang($item->user_amount) @lang($basic->currency)</td>
                                <td data-label="@lang('Max View')">@lang($item->max_show_limit)</td>
                                <td data-label="@lang('Viewed')">@lang($item->shown)</td>
                                <td data-label="@lang('Remaining')">@lang($item->remaining)</td>

                                <td data-label="@lang('Status')">
                                    @if($item->status == 0)
                                        <span class="badge badge-pill badge-dark">@lang('Deactive')</span>
                                    @elseif($item->status == 1)
                                        <span class="badge badge-pill badge-primary">@lang('Approved')</span>
                                    @elseif($item->status == 2)
                                        <span class="badge badge-pill badge-warning">@lang('Pending')</span>
                                    @elseif($item->status == 3)
                                        <span class="badge badge-pill badge-danger">@lang('Rejected')</span>
                                    @endif
                                </td>

                                    <td data-label="@lang('Action')" class="text-center">
                                            <a href="{{ route('admin.edit.advertisement',$item->id) }}"
                                                class="btn btn-outline-primary btn-rounded btn-sm editBtn"
                                            >
                                                <i class="fas fa-edit"></i>
                                            </a>

                                            <a href="javascript:void(0)"
                                                data-route="{{ route('admin.delete.advertisement',$item->id) }}"
                                                data-toggle="modal"
                                                data-target="#delete-modal"
                                                class="btn btn-outline-danger btn-rounded btn-sm notiflix-confirm"
                                            >
                                                <i class="fas fa-trash-alt"></i>
                                            </a>
                                    </td>
                            </tr>
                        @empty
                            <tr>
                                <td class="text-center text-danger" colspan="100%">@lang('No User Data')</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>

                {{ $allAds->links('partials.pagination') }}

            </div>
        </div>
    </div>

    <!-- Preview Modal -->
    <div id="adPreview" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog modal-dialog-centered modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary">
                    <h4 class="modal-title" id="primary-header-modalLabel">@lang('Preview Advertisement')</h4>
                    <button type="button" class="close" data-dismiss="modal"
                            aria-hidden="true">×
                    </button>
                </div>

                <div class="modal-body">
                    <iframe src=""
                        title="@lang('iframe ad preview')"
                        class="iframeAdView preview-type type-1 d-none"
                    >
                    </iframe>
                    <div class="youtubeEmbedLink preview-type type-2 d-none"></div>
                    <img src="" class="imgAdPreview preview-type type-3 d-none" width="768px" height="512px" alt="@lang('img ad preview')">
                    <div class="scriptPreview preview-type type-4 d-none"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-dark btn-rounded" data-dismiss="modal">@lang('Close')</button>
                </div>

            </div>
        </div>
    </div>


    <!-- Delete Modal -->
    <div id="delete-modal" class="modal fade" tabindex="-1" role="dialog"
         aria-labelledby="primary-header-modalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary">
                    <h4 class="modal-title" id="primary-header-modalLabel">@lang('Delete Confirmation')
                    </h4>
                    <button type="button" class="close" data-dismiss="modal"
                            aria-hidden="true">×
                    </button>
                </div>
                <div class="modal-body">
                    <p>@lang('Are you sure to delete this?')</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light"
                            data-dismiss="modal">@lang('Close')</button>
                    <form action="" method="post" class="deleteRoute">
                        @csrf
                        @method('delete')
                        <button type="submit" class="btn btn-primary">@lang('Yes')</button>
                    </form>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->

@endsection

@push('style-lib')
    <link href="{{asset('assets/admin/css/highlight.min.css')}}" rel="stylesheet">
@endpush
@push('js')
    <script src="{{ asset('assets/admin/js/highlight.min.js') }}"></script>
@endpush

@push('js')
    <script>
        'use strict'
        $(document).on('click','.adCategory', function() {
            var adLink = $(this).data('adlink');
            var adType = $(this).data('adtype');

            var modal = $('#adPreview');

            if (adType == 1) {
                modal.find(`.type-${adType}`).attr('src', adLink);
            }
            else if(adType == 2){
                modal.find(`.type-${adType}`).html(`${adLink}`);
                $("div.youtubeEmbedLink").find("iframe").height('450px');
                $("div.youtubeEmbedLink").find("iframe").width('100%');
            }
            else if(adType == 3){
                var imgPath = "{{asset(config('location.advertisement.path'))}}"
                var imgLink = imgPath+'/'+`${adLink}`;
                modal.find(`.type-${adType}`).attr('src', imgLink);
            }
            else if(adType == 4){
                modal.find(`.type-${adType}`).html(`<pre><code class='p-4'>${adLink}</code></pre>`);
                document.querySelectorAll(`.type-${adType} pre code`).forEach(el => {
                    hljs.highlightElement(el);
                });
            }

            $(`.type-${adType}`).removeClass('d-none');
            $(".preview-type").not(`.type-${adType}`).addClass('d-none');

            modal.modal('show');
        });

        $(document).on('click', '.notiflix-confirm', function () {
            var route = $(this).data('route');
            $('.deleteRoute').attr('action', route)
        });

        $('select').select2({
            selectOnClose: true,
            width: '100%'
        });
    </script>
@endpush
