@extends('admin.layouts.app')
@section('title')
    @lang('Edit Plan')
@endsection
@section('content')

    <div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">
        <div class="card-body">
            <div class="media mb-4 justify-content-end">
                <a href="{{route('admin.planList')}}" class="btn btn-sm  btn-primary mr-2">
                    <span><i class="fas fa-arrow-left"></i> @lang('Back')</span>
                </a>
            </div>


            <ul class="nav nav-tabs" id="myTab" role="tablist">
                @foreach($languages as $key => $language)
                    <li class="nav-item">
                        <a class="nav-link {{ $loop->first ? 'active' : '' }}" data-toggle="tab" href="#lang-tab-{{ $key }}" role="tab" aria-controls="lang-tab-{{ $key }}"
                           aria-selected="{{ $loop->first ? 'true' : 'false' }}">@lang($language->name)</a>
                    </li>
                @endforeach
            </ul>
            <div class="tab-content mt-2" id="myTabContent">
                @foreach($languages as $key => $language)

                    <div class="tab-pane fade {{ $loop->first ? 'show active' : '' }}" id="lang-tab-{{ $key }}" role="tabpanel">
                        <form method="post" action="{{ route('admin.planUpdate',[$id, $language->id]) }}" class="mt-4" enctype="multipart/form-data">
                            @csrf
                            @method('put')
                            <div class="row generate-btn-parent">
                                <div class="col-sm-12 col-md-6">
                                    <label for="name"> @lang('Plan Name') </label>
                                    <input type="text" name="name[{{ $language->id }}]"
                                            class="form-control  @error('name'.'.'.$language->id) is-invalid @enderror"
                                            value="<?php echo old('name'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->name : '') ?>" placeholder="@lang('Enter Plan name')">
                                    <div class="invalid-feedback">
                                        @error('name'.'.'.$language->id) @lang($message) @enderror
                                    </div>
                                    <div class="valid-feedback"></div>
                                </div>

                                <div class="col-sm-12 col-md-6 mb-3">
                                    <label for="tag">@lang('Tag')</label>
                                    <input type="text" name="tag[{{ $language->id }}]"
                                            class="form-control  @error('tag'.'.'.$language->id) is-invalid @enderror"
                                            value="<?php echo old('tag'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->tag : '') ?>" placeholder="@lang('Enter Tag Name')">
                                    <div class="invalid-feedback">
                                        @error('tag'.'.'.$language->id) @lang($message) @enderror
                                    </div>
                                    <div class="valid-feedback"></div>
                                </div>

                                <div class="col-sm-12 col-md-6 mb-3">
                                    <label for="short_title">@lang('Short Title') <span class="text-danger">*</span></label>
                                    <input type="text" name="short_title[{{ $language->id }}]"
                                            class="form-control  @error('short_title'.'.'.$language->id) is-invalid @enderror"
                                            value="<?php echo old('short_title'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->short_title : '') ?>" placeholder="@lang('Enter Short Title')">
                                    <div class="invalid-feedback">
                                        @error('short_title'.'.'.$language->id) @lang($message) @enderror
                                    </div>
                                    <div class="valid-feedback"></div>
                                </div>

                                @if ($loop->index == 0)
                                    <div class="col-sm-12 col-md-6">
                                        <div class="form-group">
                                            <label>@lang('Price')</label>
                                            <div class="input-group">
                                                <input type="number" name="price" class="form-control"
                                                value="<?php echo old('price'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->plan->price : '') ?>" placeholder="@lang('Enter Plan Price')">
                                                <div class="input-group-append">
                                                    <div class="input-group-text">
                                                        {{ $basic->currency ?? 'USD' }}
                                                    </div>
                                                </div>
                                            </div>
                                            @error('price')
                                                <span class="text-danger">@lang($message)</span>
                                            @enderror
                                        </div>
                                    </div>

                                    <div class="col-sm-12 col-md-6">
                                        <div class="form-group">
                                            <label for="validity">@lang('Validity') <span class="text-danger">*</span></label>
                                            <div class="input-group">
                                                <input type="number" name="validity" class="form-control"
                                                value="<?php echo old('validity'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->plan->validity : '') ?>" placeholder="@lang('Enter Validity')" min="1" step="1">
                                                <div class="input-group-append">
                                                    <div class="input-group-text">
                                                        @lang('Days')
                                                    </div>
                                                </div>
                                            </div>
                                            @error('validity')
                                                <span class="text-danger">@lang($message)</span>
                                            @enderror
                                        </div>
                                    </div>

                                    <div class="col-sm-12 col-md-6">
                                        <label>@lang('Daily Ad Limit') <span class="text-danger">*</span></label>
                                        <input type="number" name="daily_ad_limit" class="form-control" value="<?php echo old('daily_ad_limit'.$language->id, isset($planDetails[$language->id]) ? @$planDetails[$language->id][0]->plan->daily_ad_limit : '') ?>" placeholder="@lang('Enter Daily Ad Limit')" min="1" step="1">
                                        @error('daily_ad_limit')
                                            <span class="text-danger">@lang($message)</span>
                                        @enderror
                                    </div>

                                    <div class="col-sm-12 col-md-6">
                                        <label>@lang('Referral Level Commission') <span class="text-danger">*</span></label>
                                        <select name="referral_level" class="form-control" required>
                                            <option value="0"> @lang('No Referral Commission')</option>
                                            @for($i = 1; $i <= $max_referral_levels; $i++)
                                                <option value="{{$i}}" {{ $i == @$planDetails[$language->id][0]->plan->referral_level ? 'selected' : '' }}> @lang('Up to') {{$i}}  @lang('Level')</option>
                                            @endfor
                                        </select>
                                        @error('referral_level')
                                            <span class="text-danger">@lang($message)</span>
                                        @enderror
                                    </div>

                                    <div class="col-sm-6 col-md-6 col-lg-4">
                                        <label>@lang('Plan Status')</label>
                                        <div class="custom-switch-btn">
                                            <input type='hidden' value='1' name='status'>
                                            <input type="checkbox" name="status" class="custom-switch-checkbox"
                                                id="status"
                                                value="0" {{($planDetails[$language->id][0]->plan->status == 0) ? 'checked' : ''}}>
                                            <label class="custom-switch-checkbox-label" for="status">
                                                <span class="custom-switch-checkbox-inner"></span>
                                                <span class="custom-switch-checkbox-switch"></span>
                                            </label>
                                        </div>
                                        @error('status')
                                            <span class="text-danger">@lang($message)</span>
                                        @enderror
                                    </div>

                                @endif

                            </div>

                            <button type="submit" class="btn waves-effect waves-light btn-rounded btn-primary btn-block mt-3">@lang('Save')</button>
                        </form>
                    </div>
                @endforeach
            </div>
        </div>
    </div>
@endsection


@push('style-lib')
    <link href="{{ asset('assets/admin/css/bootstrap-iconpicker.min.css') }}" rel="stylesheet" type="text/css">
@endpush

@push('js-lib')
    <script src="{{ asset('assets/admin/js/bootstrap-iconpicker.bundle.min.js') }}"></script>
@endpush

@push('js')
    <script>
        "use strict";
        $(document).ready(function () {
            $('select').select2({
                selectOnClose: true
            });
        });
    </script>

    @if ($errors->any())
        @php
            $collection = collect($errors->all());
            $errors = $collection->unique();
        @endphp
        <script>
            "use strict";
            @foreach ($errors as $error)
            Notiflix.Notify.Failure("{{trans($error)}}");
            @endforeach
        </script>
    @endif
@endpush
