@extends('admin.layouts.app')
@section('title')
    @lang('Plan List')
@endsection

@section('content')

    <div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">

        <div class="card-body">
                <div class="media mb-4 float-right">
                    <a href="{{route('admin.planCreate')}}" class="btn btn-sm btn-primary mr-2">
                        <span><i class="fa fa-plus-circle"></i> @lang('Add New')</span>
                    </a>
                </div>


            <div class="table-responsive">
                <table class="categories-show-table table table-hover table-striped table-bordered" id="zero_config">
                    <thead class="thead-dark">
                    <tr>
                        <th scope="col">@lang('SL No.')</th>
                        <th scope="col">@lang('Name')</th>
                        <th scope="col">@lang('Price')</th>
                        <th scope="col">@lang('Tag')</th>
                        <th scope="col">@lang('Validity')</th>
                        <th scope="col">@lang('Limit/Day')</th>
                        <th scope="col">@lang('Referral Commission')</th>
                        <th scope="col">@lang('Status')</th>
                        <th scope="col">@lang('Action')</th>
                    </tr>
                    </thead>
                    <tbody>
                    @forelse($managePlans as $item)
                        <tr>
                            <td data-label="@lang('SL No.')">{{$loop->index+1}}</td>
                            <td data-label="@lang('Name')">
                                @lang(optional($item->details)->name)
                            </td>
                            <td data-label="@lang('Price')">
                                <p class="font-weight-bold">{{ $basic->currency_symbol ?? '$' }}{{$item->price}}</p>
                            </td>
                            <td data-label="@lang('Tag')">
                                @if (optional($item->details)->tag)
                                    @lang(optional($item->details)->tag)
                                @else
                                    @lang('N/A')
                                @endif
                            </td>

                            <td data-label="@lang('Validity')">
                                {{$item->validity}} @lang('Day')
                            </td>
                            <td data-label="@lang('Limit/Day')">
                                {{$item->daily_ad_limit}} @lang('PTC')
                            </td>
                            <td data-label="@lang('Referral Commission')">
                                @if ($item->referral_level == 0)
                                    @lang('N/A')
                                @else
                                    @lang('Up to') {{ $item->referral_level }} @lang('level')
                                @endif
                            </td>

                            <td data-label="@lang('Status')">
                                <span class="badge badge-pill badge-{{ $item->status == 0 ? 'danger' : 'success' }}">
                                    {{ $item->status == 0 ? 'Deactive' : 'Active' }}
                                </span>
                            </td>
                            <td data-label="@lang('Action')">
                                    <a href="{{ route('admin.planEdit',$item->id) }}"
                                        data-toggle="tooltip" data-original-title="@lang('Edit')"
                                        class="btn btn-outline-primary btn-rounded btn-sm editBtn">
                                        <i class="fa fa-edit" aria-hidden="true"></i>
                                    </a>

                            </td>
                        </tr>

                    @empty
                        <tr>
                            <td colspan="100%" class="text-center">@lang('No Data Found')</td>
                        </tr>
                    @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>



    <!-- Delete Modal -->
    <div id="delete-modal" class="modal fade" tabindex="-1" role="dialog"
         aria-labelledby="primary-header-modalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary">
                    <h4 class="modal-title" id="primary-header-modalLabel">@lang('Delete Confirmation')
                    </h4>
                    <button type="button" class="close" data-dismiss="modal"
                            aria-hidden="true">×
                    </button>
                </div>
                <div class="modal-body">
                    <p>@lang('Are you sure to delete this?')</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-light"
                            data-dismiss="modal">@lang('Close')</button>
                    <form action="" method="post" class="deleteRoute">
                        @csrf
                        @method('delete')
                        <button type="submit" class="btn btn-primary">@lang('Yes')</button>
                    </form>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->

@endsection


@push('style-lib')
    <link href="{{asset('assets/admin/css/dataTables.bootstrap4.css')}}" rel="stylesheet">
@endpush
@push('js')
    <script src="{{ asset('assets/admin/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('assets/admin/js/datatable-basic.init.js') }}"></script>


    @if ($errors->any())
        @php
            $collection = collect($errors->all());
            $errors = $collection->unique();
        @endphp
        <script>
            "use strict";
            @foreach ($errors as $error)
            Notiflix.Notify.Failure("{{trans($error)}}");
            @endforeach
        </script>
    @endif

    <script>
        'use strict'
        $(document).on('click', '.notiflix-confirm', function () {
            var route = $(this).data('route');
            $('.deleteRoute').attr('action', route)
        });
    </script>

@endpush
