@extends('admin.layouts.app')
@section('title', __('Facebook Login Control'))
@section('content')

    <div class="container-fluid">
        <div class="row mt-sm-4 justify-content-center">
            <div class="col-12 col-md-4 col-lg-4">
                @include('admin.plugin_panel.components.sidebar', ['settings' => config('generalsettings.social-login'), 'suffix' => ''])
            </div>

            <div class="col-12 col-md-8 col-lg-8">
                <div class="container-fluid" id="container-wrapper">
                    <div class="row justify-content-md-center">
                        <div class="col-12">
                            <div class="card mb-4 card-primary shadow">
                                <div class="card-header py-3 d-flex flex-row align-items-center bg-dark justify-content-between">
                                    <h5 class="m-0 text-white">@lang('Instructions')</h5>
                                </div>
                                <div class="card-body">
                                    @lang("To login with a Facebook account in this system, we need to have a") <a href="https://facebook.com/" target="_blank">@lang('Facebook account')</a> @lang(". This facebook account will help us to create an account with the Facebook developers account. In the developer console, we can grant access to create the Facebook Client ID and Client secret.")
                                    <br><br>
                                    @lang("Get your free 'Client ID' and 'Client secrets' from here")
                                    <a href="https://developers.facebook.com/apps/" target="_blank">@lang('Facebook Developer') <i class="fas fa-external-link-alt"></i></a>
                                    @lang(", After creating the Facebook account credentials. Now you have to put the 'Client ID' and 'Client secrets' below with your original facebook cloud dev credentials.")
                                </div>
                            </div>
                        </div>

                        <div class="col-12">
                            <div class="card mb-4 card-primary shadow">
                                <div class="card-header py-3 d-flex flex-row align-items-center bg-dark justify-content-between">
                                    <h5 class="m-0 text-white">@lang('Facebook Login Control')</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row justify-content-center">
                                        <div class="col-md-10">
                                            <form action="{{ route('admin.facebook.login.control') }}" method="post">
                                                @csrf
                                                <div class="row">
                                                    <div class="col-md-12">
                                                        <div class="form-group">
                                                            <label for="FACEBOOK_CLIENT_ID">@lang('Client Id')</label>
                                                            <input type="text" name="FACEBOOK_CLIENT_ID" value="{{ old('FACEBOOK_CLIENT_ID',env('FACEBOOK_CLIENT_ID')) }}" placeholder="@lang('Client Id')"
                                                                class="form-control @error('FACEBOOK_CLIENT_ID') is-invalid @enderror">
                                                            <div class="invalid-feedback">@error('FACEBOOK_CLIENT_ID') @lang($message) @enderror</div>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-12">
                                                        <div class="form-group">
                                                            <label for="FACEBOOK_CLIENT_SECRET">@lang('Client Secret')</label>
                                                            <input type="text" name="FACEBOOK_CLIENT_SECRET" value="{{ old('FACEBOOK_CLIENT_SECRET',env('FACEBOOK_CLIENT_SECRET')) }}" placeholder="@lang('Client Secret')"
                                                                class="form-control @error('FACEBOOK_CLIENT_SECRET') is-invalid @enderror">
                                                            <div class="invalid-feedback">@error('FACEBOOK_CLIENT_SECRET') @lang($message) @enderror</div>
                                                        </div>
                                                    </div>

                                                    <div class="col-sm-6 col-md-6 col-lg-6">
                                                        <div class="form-group ">
                                                            <label>@lang('Login Status')</label>
                                                            <div class="custom-switch-btn w-md-100">
                                                                <input type='hidden' value="1" name='facebook_status_login'>
                                                                <input type="checkbox" name="facebook_status_login" class="custom-switch-checkbox" id="facebook_status_login"  value = "0" <?php if( $basicControl->facebook_status_login == 0):echo 'checked'; endif ?> >
                                                                <label class="custom-switch-checkbox-label" for="facebook_status_login">
                                                                    <span class="custom-switch-checkbox-inner"></span>
                                                                    <span class="custom-switch-checkbox-switch"></span>
                                                                </label>
                                                            </div>
                                                            @error('facebook_status_login')
                                                                <span class="text-danger">{{ $message }}</span>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                    <div class="col-sm-6 col-md-6 col-lg-6">
                                                        <div class="form-group ">
                                                            <label>@lang('Registration Status')</label>
                                                            <div class="custom-switch-btn w-md-100">
                                                                <input type='hidden' value="1" name='facebook_status_registration'>
                                                                <input type="checkbox" name="facebook_status_registration" class="custom-switch-checkbox" id="facebook_status_registration"  value = "0" <?php if( $basicControl->facebook_status_registration == 0):echo 'checked'; endif ?> >
                                                                <label class="custom-switch-checkbox-label" for="facebook_status_registration">
                                                                    <span class="custom-switch-checkbox-inner"></span>
                                                                    <span class="custom-switch-checkbox-switch"></span>
                                                                </label>
                                                            </div>
                                                            @error('facebook_status_registration')
                                                                <span class="text-danger">{{ $message }}</span>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="form-group mt-2">
                                                    <button type="submit" name="submit"
                                                            class="btn btn-primary btn-rounded btn-block">@lang('Save changes')</button>
                                                </div>
                                            </form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
