@extends('admin.layouts.app')
@section('title', __('GitHub Login Control'))
@section('content')

    <div class="container-fluid">
        <div class="row mt-sm-4 justify-content-center">
            <div class="col-12 col-md-4 col-lg-4">
                @include('admin.plugin_panel.components.sidebar', ['settings' => config('generalsettings.social-login'), 'suffix' => ''])
            </div>

            <div class="col-12 col-md-8 col-lg-8">
                <div class="container-fluid" id="container-wrapper">
                    <div class="row justify-content-md-center">
                        <div class="col-12">
                            <div class="card mb-4 card-primary shadow">
                                <div class="card-header py-3 d-flex flex-row align-items-center bg-dark justify-content-between">
                                    <h5 class="m-0 text-white">@lang('Instructions')</h5>
                                </div>
                                <div class="card-body">
                                    @lang("To login with a GitHub account in this system, we need to have a") <a href="https://github.com/" target="_blank">@lang('GitHub account')</a> @lang(". This github account will help us to create an account with the GitHub developers account. In the developer console, we can grant access to create the GitHub Client ID and Client secret.")
                                    <br><br>
                                    @lang("Get your free 'Client ID' and 'Client secrets' from here")
                                    <a href="https://github.com/settings/developers" target="_blank">@lang('GitHub Developers Console') <i class="fas fa-external-link-alt"></i></a>
                                    @lang(", After creating the GitHub account credentials. Now you have to put the 'Client ID' and 'Client secrets' below with your original github cloud dev credentials.")
                                    <a href="{{asset('assets/uploads/socialLogin/loginWithGitHub.png')}}" target="_blank">@lang('Click here')</a>@lang(' to see demo image.')
                                </div>
                            </div>
                        </div>

                        <div class="col-12">
                            <div class="card mb-4 card-primary shadow">
                                <div class="card-header py-3 d-flex flex-row align-items-center bg-dark justify-content-between">
                                    <h5 class="m-0 text-white">@lang('GitHub Login Control')</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row justify-content-center">
                                        <div class="col-md-10">
                                            <form action="{{ route('admin.github.login.control') }}" method="post">
                                                @csrf
                                                <div class="row">
                                                    <div class="col-md-12">
                                                        <div class="form-group">
                                                            <label for="GITHUB_CLIENT_ID">@lang('Client Id')</label>
                                                            <input type="text" name="GITHUB_CLIENT_ID" value="{{ old('client_id',env('GITHUB_CLIENT_ID')) }}" placeholder="@lang('Client Id')"
                                                                class="form-control @error('GITHUB_CLIENT_ID') is-invalid @enderror">
                                                            <div class="invalid-feedback">@error('GITHUB_CLIENT_ID') @lang($message) @enderror</div>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-12">
                                                        <div class="form-group">
                                                            <label for="GITHUB_CLIENT_SECRET">@lang('Client Secret')</label>
                                                            <input type="text" name="GITHUB_CLIENT_SECRET" value="{{ old('GITHUB_CLIENT_SECRET',env('GITHUB_CLIENT_SECRET')) }}" placeholder="@lang('Client Secret')"
                                                                class="form-control @error('GITHUB_CLIENT_SECRET') is-invalid @enderror">
                                                            <div class="invalid-feedback">@error('GITHUB_CLIENT_SECRET') @lang($message) @enderror</div>
                                                        </div>
                                                    </div>

                                                    <div class="col-sm-6 col-md-6 col-lg-6">
                                                        <div class="form-group ">
                                                            <label>@lang('Login Status')</label>
                                                            <div class="custom-switch-btn w-md-100">
                                                                <input type='hidden' value="1" name='github_status_login'>
                                                                <input type="checkbox" name="github_status_login" class="custom-switch-checkbox" id="github_status_login"  value = "0" <?php if( $basicControl->github_status_login == 0):echo 'checked'; endif ?> >
                                                                <label class="custom-switch-checkbox-label" for="github_status_login">
                                                                    <span class="custom-switch-checkbox-inner"></span>
                                                                    <span class="custom-switch-checkbox-switch"></span>
                                                                </label>
                                                            </div>
                                                            @error('github_status_login')
                                                                <span class="text-danger">{{ $message }}</span>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                    <div class="col-sm-6 col-md-6 col-lg-6">
                                                        <div class="form-group ">
                                                            <label>@lang('Registration Status')</label>
                                                            <div class="custom-switch-btn w-md-100">
                                                                <input type='hidden' value="1" name='github_status_registration'>
                                                                <input type="checkbox" name="github_status_registration" class="custom-switch-checkbox" id="github_status_registration"  value = "0" <?php if( $basicControl->github_status_registration == 0):echo 'checked'; endif ?> >
                                                                <label class="custom-switch-checkbox-label" for="github_status_registration">
                                                                    <span class="custom-switch-checkbox-inner"></span>
                                                                    <span class="custom-switch-checkbox-switch"></span>
                                                                </label>
                                                            </div>
                                                            @error('github_status_registration')
                                                                <span class="text-danger">{{ $message }}</span>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="form-group mt-2">
                                                    <button type="submit" name="submit"
                                                            class="btn btn-primary btn-rounded btn-block">@lang('Save changes')</button>
                                                </div>
                                            </form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
