@extends('admin.layouts.app')
@section('title',trans('Ads View Earning Log').' : '.$user->username )

@section('content')

    <div class="page-header card card-primary m-0 m-md-4 my-4 m-md-0 p-5 shadow">
        <div class="row justify-content-between">
            <div class="col-md-12">
                <form action="{{route('admin.user.ads.view.log.search', $userid)}}" method="get">
                    <div class="row">
                        <div class="col-md-3">
                            <div class="form-group">
                                <input type="text" name="ads_name" value="{{old('ads_name',@request()->ads_name)}}" class="form-control" placeholder="@lang('Search by Advertisement Name')">
                            </div>
                        </div>

                        <div class="col-md-3">
                            <select name="ads_type" class="form-select" aria-label="Default select example">
                                <option value="">@lang('Advertisement Type')</option>
                                <option value="1"
                                        @if(@request()->ads_type == '1') selected @endif>@lang('URL/Link')</option>
                                <option value="2"
                                        @if(@request()->ads_type == '2') selected @endif>@lang('Youtube Embeded Link')</option>
                                <option value="3"
                                        @if(@request()->ads_type == '3') selected @endif>@lang('Picture/Banner')</option>
                                <option value="4"
                                        @if(@request()->ads_type == '4') selected @endif>@lang('Code/Script')</option>
                            </select>
                        </div>

                        <div class="col-md-3">
                            <div class="form-group">
                                <input type="date" class="form-control" name="datetrx" id="datepicker" value="{{@request()->datetrx}}"/>
                            </div>
                        </div>

                        <div class="col-md-3">
                            <div class="form-group">
                                <button type="submit" class="btn btn-block btn-primary"><i class="fas fa-search"></i> @lang('Search')</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>



    <div class="card card-primary m-0 m-md-4 my-4 m-md-0 shadow">
        <div class="card-body">
            <table class="categories-show-table table table-hover table-striped table-bordered">
                <thead class="thead-dark">
                <tr>
                    <th scope="col">@lang('SL No.')</th>
                    <th scope="col">@lang('Advertisement Name')</th>
                    <th scope="col">@lang('Advertisement Type')</th>
                    <th scope="col">@lang('Earned Amount')</th>
                    <th scope="col">@lang('Date-Time')</th>
                </tr>
                </thead>
                <tbody>
                @forelse($earnFromAd as $key => $item)
                    <tr>
                        <td data-label="@lang('SL No.')">{{++$key}}</td>
                        <td data-label="@lang('Advertisement Name')">
                            <a href="{{ route('admin.edit.advertisement',$item->ptc_id) }}" target="_blank">
                                @lang(Illuminate\Support\Str::limit((optional($item->advertisement)->ads_name),30))
                            </a>
                        </td>
                        <td data-label="@lang('Advertisement Type')">
                            <button class="previewAd btn btn-transparent">
                                @if(optional($item->advertisement)->ads_type == 1)
                                    <span class="badge badge-pill badge-primary adCategory"
                                        data-adlink="{{ optional($item->advertisement)->ads_body }}"
                                        data-adtype="{{ optional($item->advertisement)->ads_type }}"
                                    >
                                        @lang('URL/Link')
                                    </span>
                                @elseif(optional($item->advertisement)->ads_type == 2)
                                    <span class="badge badge-pill badge-danger adCategory"
                                        data-adlink="{{ optional($item->advertisement)->ads_body }}"
                                        data-adtype="{{ optional($item->advertisement)->ads_type }}"
                                    >
                                        @lang('Youtube Embeded Link')
                                    </span>
                                @elseif(optional($item->advertisement)->ads_type == 3)
                                    <span class="badge badge-pill badge-success adCategory"
                                        data-adlink="{{ optional($item->advertisement)->ads_body }}"
                                        data-adtype="{{ optional($item->advertisement)->ads_type }}"
                                    >
                                        @lang('Picture/Banner')
                                    </span>
                                @elseif(optional($item->advertisement)->ads_type == 4)
                                    <span class="badge badge-pill badge-dark adCategory"
                                        data-adlink="{{ optional($item->advertisement)->ads_body }}"
                                        data-adtype="{{ optional($item->advertisement)->ads_type }}"
                                    >
                                        @lang('Code/Script')
                                    </span>
                                @endif
                            </button>
                        </td>
                        <td data-label="@lang('Earned Amount')">{{getAmount($item->amount)}} @lang($basic->currency)</td>
                        <td data-label="@lang('Date-Time')">
                            {{ dateTime($item->created_at, 'd M Y h:i A') }}
                        </td>

                    </tr>
                @empty
                    <tr>
                        <td class="text-center text-danger" colspan="100%">@lang('No User Data')</td>
                    </tr>
                @endforelse
                </tbody>
            </table>

            {{ $earnFromAd->links('partials.pagination') }}

        </div>
    </div>

    <!-- Preview Modal -->
    <div id="adPreview" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog modal-dialog-centered modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary">
                    <h4 class="modal-title" id="primary-header-modalLabel">@lang('Preview Advertisement')</h4>
                    <button type="button" class="close" data-dismiss="modal"
                            aria-hidden="true">×
                    </button>
                </div>

                <div class="modal-body">
                    <iframe src=""
                        title="@lang('iframe ad preview')"
                        class="iframeAdView preview-type type-1 d-none"
                    >
                    </iframe>
                    <div class="youtubeEmbedLink preview-type type-2 d-none"></div>
                    <img src="" class="imgAdPreview preview-type type-3 d-none" width="768px" height="512px" alt="@lang('img ad preview')">
                    <div class="scriptPreview preview-type type-4 d-none"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-dark btn-rounded" data-dismiss="modal">@lang('Close')</button>
                </div>

            </div>
        </div>
    </div>

@endsection

@push('style-lib')
    <link href="{{asset('assets/admin/css/highlight.min.css')}}" rel="stylesheet">
@endpush
@push('js')
    <script src="{{ asset('assets/admin/js/highlight.min.js') }}"></script>
@endpush


@push('js')
    <script>
        'use strict'
        $(document).on('click','.adCategory', function() {
            var adLink = $(this).data('adlink');
            var adType = $(this).data('adtype');

            var modal = $('#adPreview');

            if (adType == 1) {
                modal.find(`.type-${adType}`).attr('src', adLink);
            }
            else if(adType == 2){
                modal.find(`.type-${adType}`).html(`${adLink}`);
                $("div.youtubeEmbedLink").find("iframe").height('450px');
                $("div.youtubeEmbedLink").find("iframe").width('100%');
            }
            else if(adType == 3){
                var imgPath = "{{asset(config('location.advertisement.path'))}}"
                var imgLink = imgPath+'/'+`${adLink}`;
                modal.find(`.type-${adType}`).attr('src', imgLink);
            }
            else if(adType == 4){
                modal.find(`.type-${adType}`).html(`<pre><code class='p-4'>${adLink}</code></pre>`);
                document.querySelectorAll(`.type-${adType} pre code`).forEach(el => {
                    hljs.highlightElement(el);
                });
            }

            $(`.type-${adType}`).removeClass('d-none');
            $(".preview-type").not(`.type-${adType}`).addClass('d-none');

            modal.modal('show');
        });

        $(document).on('click', '.notiflix-confirm', function () {
            var route = $(this).data('route');
            $('.deleteRoute').attr('action', route)
        });

        $('select').select2({
            selectOnClose: true,
            width: '100%'
        });
    </script>
@endpush
