@extends($theme.'layouts.app')
@section('title',trans('Login'))

@section('content')
    <section class="login-section">
        <div class="container h-100">
            <div class="row h-100 justify-content-center">
                <div class="col-lg-6">
                    <div class="form-wrapper d-flex align-items-center h-100">
                        <form action="{{ route('login') }}" method="post">
                            @csrf
                            <div class="row g-4">
                                <div class="col-12">
                                    <h4>@lang('Login here')</h4>
                                </div>
                                <div class="input-box col-12">
                                    <input type="text" name="username" value="{{old('username')}}" class="form-control"
                                           placeholder="@lang('Email Or Username')"/>
                                    @error('username')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                    @error('email')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>
                                <div class="input-box col-12">
                                    <input type="password" name="password" placeholder="@lang('Password')"
                                           class="form-control"/>
                                    @error('password')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <input type="hidden" name="timezone" class="timeZone" value="">

                                @if(basicControl()->reCaptcha_status_login)
                                    <div class="input-box col-12">
                                        {!! NoCaptcha::renderJs(session()->get('trans')) !!}
                                        {!! NoCaptcha::display() !!}
                                        @error('g-recaptcha-response')
                                        <span class="text-danger">@lang($message)</span>
                                        @enderror
                                    </div>
                                @endif

                                <div class="col-12">
                                    <div class="links">
                                        <div class="form-check">
                                            <input class="form-check-input" type="checkbox" name="remember"
                                                   {{ old('remember') ? 'checked' : '' }} value=""
                                                   id="flexCheckDefault"/>
                                            <label class="form-check-label"
                                                   for="flexCheckDefault"> @lang('Remember me') </label>
                                        </div>
                                        <a href="{{ route('password.request') }}">@lang('Forgot password?')</a>
                                    </div>
                                </div>
                            </div>

                            <button type="submit" class="btn-custom w-100">@lang('sign in')</button>

                            @if(config('basic.registration'))
                            <div class="bottom">
                                @lang("Don't have an account?")
                                <a href="{{ route('register') }}">@lang('Create account')</a>
                            </div>
                            @endif

                            @if(basicControl()->google_status_login || basicControl()->facebook_status_login || basicControl()->github_status_login)
                                <div class="divider"><span>@lang('or sign in with')</span></div>
                                <div class="social-links">
                                    @if(basicControl()->google_status_login)
                                        <a href="{{ route('social.oauth', 'google') }}" class="google">
                                            <i class="fab fa-google"></i>
                                        </a>
                                    @endif
                                    @if(basicControl()->facebook_status_login)
                                        <a href="{{ route('social.oauth', 'facebook') }}" class="facebook">
                                            <i class="fab fa-facebook-f"></i>
                                        </a>
                                    @endif
                                    @if(basicControl()->github_status_login)
                                        <a href="{{ route('social.oauth', 'github') }}" class="github">
                                            <i class="fab fa-github"></i>
                                        </a>
                                    @endif
                                </div>
                            @endif
                        </form>


                    </div>

                </div>
            </div>
        </div>
    </section>
@endsection


@push('script')
    <script>
        var getTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;
        $('.timeZone').val(getTimeZone);
    </script>
@endpush
