@extends($theme.'layouts.app')
@section('title',trans('Register'))

@section('content')
    <section class="login-section">
        <div class="container h-100">
            <div class="row h-100 justify-content-center">
                <div class="col-lg-8">
                    <div class="form-wrapper d-flex align-items-center h-100">
                        <form action="{{ route('register') }}" method="post">
                            @csrf
                            <div class="row g-4">
                                <div class="col-12">
                                    <h4>@lang('register here')</h4>
                                </div>

                                @if(session()->get('sponsor') != null)
                                    <div class="input-box col-md-12">
                                        <div class="form-group mb-30">
                                            <label>@lang('Sponsor Name')</label>
                                            <input type="text" name="sponsor" class="form-control" id="sponsor"
                                                   placeholder="{{trans('Sponsor By') }}"
                                                   value="{{session()->get('sponsor')}}" readonly>
                                        </div>
                                    </div>
                                @endif

                                <div class="input-box col-6">
                                    <input type="text" name="firstname" value="{{old('firstname')}}"
                                           placeholder="@lang('First Name')" class="form-control"/>
                                    @error('firstname')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <div class="input-box col-6">
                                    <input type="text" name="lastname" value="{{old('lastname')}}"
                                           placeholder="@lang('Last Name')" class="form-control"/>
                                    @error('lastname')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <div class="input-box col-6">
                                    <input type="text" name="username" value="{{old('username')}}"
                                           placeholder="@lang('Username')" class="form-control"/>
                                    @error('username')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <div class="input-box col-6">
                                    <input type="email" name="email" value="{{old('email')}}"
                                           placeholder="@lang('Email Address')" class="form-control"/>
                                    @error('email')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <div class="input-box col-md-12">
                                    @php
                                        $country_code = (string) @getIpInfo()['code'] ?: null;
                                        $myCollection = collect(config('country'))->map(function($row) {
                                            return collect($row);
                                        });
                                        $countries = $myCollection->sortBy('code');
                                    @endphp

                                    <div class="input-group">
                                        <div class="input-group-prepend w-50">
                                            <select name="phone_code" class="form-control country_code dialCode-change">
                                                @foreach(config('country') as $value)
                                                    <option value="{{$value['phone_code']}}"
                                                            data-name="{{$value['name']}}"
                                                            data-code="{{$value['code']}}"
                                                        {{$country_code == $value['code'] ? 'selected' : ''}}
                                                    > {{$value['name']}} ({{$value['phone_code']}})

                                                    </option>
                                                @endforeach
                                            </select>
                                        </div>
                                        <input type="text" name="phone" class="form-control dialcode-set ms-1"
                                               value="{{old('phone')}}" placeholder="@lang('Your Phone Number')">
                                    </div>

                                    @error('phone')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror

                                    <input type="hidden" name="country_code" value="{{old('country_code')}}"
                                           class="text-dark">
                                </div>

                                <div class="input-box col-6">
                                    <input type="password" name="password" placeholder="@lang('Password')"
                                           class="form-control"/>
                                    @error('password')
                                    <span class="text-danger mt-1">@lang($message)</span>
                                    @enderror
                                </div>

                                <div class="input-box col-6">
                                    <input type="password" name="password_confirmation"
                                           placeholder="@lang('Confirm Password')" class="form-control"/>
                                </div>

                                <input type="hidden" name="timezone" class="timeZone" value="">

                                @if(basicControl()->reCaptcha_status_registration)
                                    <div class="input-box col-md-12">
                                        {!! NoCaptcha::renderJs(session()->get('trans')) !!}
                                        {!! NoCaptcha::display() !!}
                                        @error('g-recaptcha-response')
                                        <span class="text-danger mt-1">@lang($message)</span>
                                        @enderror
                                    </div>
                                @endif

                                <div class="col-12">
                                    <div class="links">
                                        <div class="form-check">
                                            <input class="form-check-input" type="checkbox" value=""
                                                   id="flexCheckDefault"/>
                                            <label class="form-check-label" for="flexCheckDefault">
                                                @lang('I Agree with the Terms & conditions')
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <button type="submit" class="btn-custom w-100">@lang('sign up')</button>
                            <div class="bottom">
                                @lang('Already have an account?')
                                <a href="{{ route('login') }}">@lang('Login here')</a>
                            </div>

                            @if(basicControl()->google_status_registration || basicControl()->facebook_status_registration || basicControl()->github_status_registration)
                                <div class="divider"><span>@lang('or sign in with')</span></div>
                                <div class="social-links">
                                    @if(basicControl()->google_status_registration)
                                        <a href="{{ route('social.oauth', 'google') }}" class="google">
                                            <i class="fab fa-google"></i>
                                        </a>
                                    @endif
                                    @if(basicControl()->facebook_status_registration)
                                        <a href="{{ route('social.oauth', 'facebook') }}" class="facebook">
                                            <i class="fab fa-facebook-f"></i>
                                        </a>
                                    @endif
                                    @if(basicControl()->github_status_registration)
                                        <a href="{{ route('social.oauth', 'github') }}" class="github">
                                            <i class="fab fa-github"></i>
                                        </a>
                                    @endif
                                </div>
                            @endif

                        </form>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('script')
    <script>
        "use strict";
        $(document).ready(function () {
            setDialCode();
            $(document).on('change', '.dialCode-change', function () {
                setDialCode();
            });

            function setDialCode() {
                let currency = $('.dialCode-change').val();
                $('.dialcode-set').val(currency);
            }
        });

        var getTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;
        $('.timeZone').val(getTimeZone);
    </script>
@endpush
