@extends($theme.'layouts.app')
@section('title', trans($title))

@section('content')
    <!-- BLOG -->
    <section class="blog-page blog-details">
        <div class="container">
            <div class="row g-lg-5">
                <div class="col-lg-8">
                    @forelse ($allBlogs as $blog)
                        @isset($blog->details)
                            <div class="blog-box">
                                <div class="img-box">
                                    <img src="{{getFile(config('location.blog.path').$blog->image)}}" class="img-fluid" alt="@lang('blog img')" />
                                </div>
                                <div class="text-box">
                                    <div class="date-author flex-wrap">
                                        <div class="d-flex">
                                            <span><i class="fal fa-clock"></i> {{dateTime($blog->created_at,'d M, Y')}}</span>
                                            <span class="ms-3"><i class="fal fa-user-circle"></i> @lang(optional($blog->details)->author)</span>
                                        </div>
                                        <span><i class="fal fa-tags"></i> @lang(optional(optional($blog->category)->details)->name)</span>
                                    </div>
                                    <h5 class="title">@lang(\Illuminate\Support\Str::limit(optional($blog->details)->title,90))</h5>
                                    <p>{!! trans(\Illuminate\Support\Str::limit(optional($blog->details)->details,300)) !!}</p>
                                    <a href="{{route('blogDetails',[slug(optional($blog->details)->title), $blog->id])}}" class="btn-custom mt-3">@lang('Read More')</a>
                                </div>
                            </div>
                        @endisset
                    @empty
                        <div class="d-flex flex-column justify-content-center align-items-center py-5">
                            <h2 class="text-center">@lang('Opps!')</h2>
                            <h3 class="text-center greenColorText mb-3">@lang('No Blog Post Available.')</h3>

                            <a href="{{ request()->routeIs('blog') ? route('home') : route('blog')  }}" class="btn-custom mt-4 text-center"><i class="fas fa-arrow-left"></i> @lang('Back')</a>
                        </div>
                    @endforelse

                    <div class="row py-5 mt-5">
                        {{ $allBlogs->appends($_GET)->links($theme.'partials.pagination') }}
                    </div>

                    <!-- <div id="shareBlock">Share now</div> -->
                </div>

                <div class="col-lg-4">
                    <div class="side-bar">
                        <div class="side-box">
                            <form action="{{ route('blogSearch') }}" method="get">
                                @csrf
                                <h4>@lang('Search here')</h4>
                                <div class="input-group">
                                    <input type="text" class="form-control" name="search" id="search" placeholder="@lang('search here...')"/>
                                    <button type="submit"><i class="fal fa-search" aria-hidden="true"></i></button>
                                </div>
                            </form>
                        </div>

                        @if (count($recentBlogs) > 0)
                            <div class="side-box">
                                <h4>@lang('Recent Posts')</h4>
                                @foreach ($recentBlogs->take(3)->sortDesc()->shuffle() as $blog)
                                    @isset($blog->details)
                                        <div class="blog-box">
                                            <div class="img-box">
                                                <a href="{{route('blogDetails',[slug(@$blog->details->title), $blog->id])}}">
                                                    <img class="img-fluid" src="{{ getFile(config('location.blog.path'). @$blog->image) }}" alt="@lang('related blog img')" />
                                                </a>
                                            </div>
                                            <div class="text-box">
                                                <span class="date">{{dateTime($blog->created_at,'d M, Y')}}</span>
                                                <a href="{{route('blogDetails',[slug(@$blog->details->title), $blog->id])}}" class="title"
                                                >@lang(\Illuminate\Support\Str::limit(optional($blog->details)->title,45))
                                                </a>
                                            </div>
                                        </div>
                                    @endisset
                                @endforeach
                            </div>
                        @endif

                        <div class="side-box">
                            <h4>@lang('categories')</h4>
                            <ul class="links">
                                @foreach ($blogCategory as $category)
                                    @isset($category->details)
                                        <li>
                                            <a href="{{ route('CategoryWiseBlog', [slug(optional($category->details)->name), $category->id]) }}">
                                                @lang(optional($category->details)->name) ({{$category->blog_count}})
                                            </a>
                                        </li>
                                    @endisset
                                @endforeach
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- /BLOG -->
@endsection
