@if(0 < count($plans))
    @if(isset($templates['plan'][0]) && $plan = $templates['plan'][0])
        <section class="pricing-section">
            <div class="container">
                @if(request()->routeIs('home'))
                    <div class="row">
                        <div class="col-12">
                            <div class="header-text text-center">
                                <h5>@lang(optional($plan->description)->title)</h5>
                                <h2>@lang(optional($plan->description)->sub_title)</h2>
                            </div>
                        </div>
                    </div>
                @endif

                <div class="row g-4 g-lg-5">
                    @foreach ($plans as $data)
                        <div class="col-lg-4 col-md-6">
                            <div class="pricing-box" data-aos="fade-up" data-aos-duration="1000" data-aos-anchor-placement="center-bottom">
                                <h4>@lang(optional($data->details)->name) @lang('Plan')</h4>
                                @if($data->price == 0)
                                    <h1>@lang('Free')</h1>
                                @else
                                    <h1>@lang($basic->currency_symbol ?? '$'){{getAmount($data->price)}}</h1>
                                @endif
                                <p>@lang(optional($data->details)->short_title)</p>
                                <ul>
                                    <li><i class="fal fa-check-circle text-success"></i>@lang('Period') : {{$data->validity}} @lang('Days')</li>
                                    <li><i class="fal fa-check-circle text-success"></i>@lang('Daily Ad Limit') : {{$data->daily_ad_limit}} @lang('PTC')</li>
                                    <li>
                                        @if($data->referral_level == 0)
                                            <i class="fal fa-times-circle text-danger"></i>
                                        @else
                                            <i class="fal fa-check-circle text-success"></i>
                                        @endif

                                        @lang('Referral Bonus') :
                                        @if ($data->referral_level == 0)
                                            @lang('N/A')
                                        @else
                                            @lang('Up to') {{ $data->referral_level }} @lang('level')
                                        @endif
                                    </li>
                                </ul>

                                @if(isset($freePlan->free_plan_purchased) && $freePlan->free_plan_purchased == 1 && $data->price == 0)
                                    <button class="btn-custom w-100 disabled">
                                        <del>@lang('Purchase Plan')</del>
                                    </button>
                                @else
                                    <button class="btn-custom w-100 purchaseNow"
                                            data-bs-toggle="modal"
                                            data-bs-target="#planModal"
                                            data-price="{{$data->price}}"
                                            data-resource="{{$data->details}}"
                                    >
                                        @lang('Purchase Plan')
                                    </button>
                                @endif

                                @if(optional($data->details)->tag)
                                    <span class="feature">@lang(optional($data->details)->tag)</span>
                                @endif
                            </div>
                        </div>
                    @endforeach
                 </div>
            </div>
        </section>


        <!--Plan Modal -->
        <div id="planModal" class="modal fade modal-with-form" data-bs-backdrop="static" tabindex="-1" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered">

                <!-- Modal content-->
                <div class="modal-content form-block">
                    <div class="modal-header">
                        <h4 class="modal-title">@lang('Purchase Plan')</h4>
                        <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>
                    <form class="login-form" id="invest-form" action="{{route('user.purchase-plan')}}" method="post">
                        @csrf
                        <div class="modal-body">
                            <div class="form-group">
                                @auth
                                    <h3 class="text-green text-center plan-name"></h3>
                                    <h4 class="text-center plan-price"></h4>
                                    <input type="hidden" name="plan_id" class="plan-id">
                                    @if(auth()->user()->plan_id || auth()->user()->plan_id != 0)
                                        <small class="d-block mb-0 pb-0 text-muted mt-4">@lang('If you purchase this plan. Your prior plan feature will reset according to this plan.')</small>
                                    @endif
                                @else
                                    <h5 class="text-center py-2">@lang('Please at first login to your account to purchase plan.')</h5>
                                @endauth
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                            @auth
                                <button type="submit" class="btn-custom">@lang('Purchase Now')</button>
                            @else
                                <a href="{{ route('login') }}" class="btn-custom">@lang('Login')</a>
                            @endauth
                        </div>

                    </form>
                </div>

            </div>
        </div>

    @endif
@endif

@if(request()->routeIs('plan') && 0 >= count($plans))
    <div class="pricing-section d-flex flex-column justify-content-center align-items-center py-5">
        <h2 class="text-center">@lang('Opps!')</h2>
        <h3 class="text-center greenColorText mb-3">@lang('No Plan Available.')</h3>

        <a href="{{ route('home') }}" class="btn-custom mt-4 text-center">
            <i class="fas fa-arrow-left"></i> @lang('Back')
        </a>
    </div>
@endif


@push('script')
    <script>
        "use strict";

        $(document).on('click', '.purchaseNow', function () {
            let data = $(this).data('resource');
            let price = $(this).data('price');

            let symbol = "{{trans($basic->currency_symbol)}}";

            $('.plan-price').text(`@lang('Price'): ${symbol}${price}`);

            $('.plan-name').text(`${data.name} @lang('Plan')`);
            $('.plan-id').val(data.plan_id);
        });

        $(document).on('click', '.disabled', function (){
            Notiflix.Notify.Failure("@lang('You can use this plan only once. Please purchase new one.')");
        })

    </script>


    @if(count($errors) > 0 )
        <script>
            @foreach($errors->all() as $key => $error)
            Notiflix.Notify.Failure("@lang($error)");
            @endforeach
        </script>
    @endif

@endpush
