@extends($theme.'layouts.user')
@section('title')
    @lang('Add Fund')
@endsection
@section('content')

    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang('Add Fund')</h2>
            </div>

            <div class="feature-wrapper top-0 add-fund">
                <div class="row g-3">
                @foreach($gateways as $key => $gateway)
                    <div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 col-6">
                        <div class="card card-type-1 text-center bgGateway p-3">

                            <div class="card-icon">
                                <img src="{{ getFile(config('location.gateway.path').$gateway->image)}}"
                                     alt="{{trans($gateway->name)}}" class="gateway gatewayImage">
                            </div>

                            <button type="button"
                                    data-id="{{$gateway->id}}"
                                    data-name="{{$gateway->name}}"
                                    data-currency="{{$gateway->currency}}"
                                    data-gateway="{{$gateway->code}}"
                                    data-min_amount="{{getAmount($gateway->min_amount, $basic->fraction_number)}}"
                                    data-max_amount="{{getAmount($gateway->max_amount,$basic->fraction_number)}}"
                                    data-percent_charge="{{getAmount($gateway->percentage_charge,$basic->fraction_number)}}"
                                    data-fix_charge="{{getAmount($gateway->fixed_charge, $basic->fraction_number)}}"
                                    class="btn-custom addFund" data-keyboard='false'
                                    data-bs-toggle="modal" data-bs-target="#addFundModal">@lang('Pay Now')
                            </button>

                        </div>
                    </div>
                @endforeach
                </div>
            </div>
        </div>
    </div>


    @push('loadModal')
        <div id="addFundModal" class="modal fade addFundModal" tabindex="-1" role="dialog" data-bs-backdrop="static">
            <div class="modal-dialog modal-dialog-centered modal-md">
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title method-name" id="editModalLabel"></h4>
                        <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>

                    <div class="modal-body">
                        <form>
                            <div class="payment-form">
                                @if(0 == $totalPayment)
                                    <p class="text-danger depositLimit fw-bold"></p>
                                    <p class="text-danger depositCharge fw-bold"></p>
                                @endif

                                <input type="hidden" class="gateway" name="gateway" value="">

                                <div class="form-group">
                                    <label class="mb-1">@lang('Amount')</label>
                                    <div class="input-group input-box bg-transparent">
                                        <input type="text" class="amount form-control" name="amount" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" required placeholder="@lang('Enter Amount')"
                                               @if($totalPayment != null) value="{{$totalPayment}}" readonly @endif>
                                        <span class="input-group-text show-currency border-0"></span>
                                    </div>
                                    <pre class="text-danger errors"></pre>
                                </div>
                            </div>
                        </form>

                        <div class="payment-info text-center">
                            <img class="w-15" id="loading" src="{{asset('assets/admin/images/loading.gif')}}" alt="@lang('loader')"/>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                        <button type="button" class="btn-custom checkCalc">@lang('Next')</button>
                    </div>

                </div>
            </div>
        </div>
    @endpush


@endsection



@push('script')

    <script>

        "use strict";
        $(document).ready(function (){
            $('#loading').hide();
        })
        var id, minAmount, maxAmount, baseSymbol, fixCharge, percentCharge, currency, amount, gateway;
        $(document).on('click','.addFund', function () {
            id = $(this).data('id');
            gateway = $(this).data('gateway');
            minAmount = $(this).data('min_amount');
            maxAmount = $(this).data('max_amount');
            baseSymbol = "{{config('basic.currency_symbol')}}";
            fixCharge = $(this).data('fix_charge');
            percentCharge = $(this).data('percent_charge');
            currency = $(this).data('currency');
            $('.depositLimit').text(`@lang('Transaction Limit:') ${minAmount} - ${maxAmount}  ${baseSymbol}`);

            var depositCharge = `@lang('Charge:') ${fixCharge} ${baseSymbol}  ${(0 < percentCharge) ? ' + ' + percentCharge + ' % ' : ''}`;
            $('.depositCharge').text(depositCharge);

            $('.method-name').text(`@lang('Payment By') ${$(this).data('name')} - ${currency}`);
            $('.show-currency').text("{{config('basic.currency')}}");
            $('.gateway').val(currency);

            // amount
        });


        $(document).on('click',".checkCalc", function () {
            $('.payment-form').addClass('d-none');

            $('#loading').show();
            $('.modal-backdrop.fade').addClass('show');
            amount = $('.amount').val();
            $.ajax({
                url: "{{route('user.addFund.request')}}",
                type: 'POST',
                data: {
                    amount,
                    gateway
                },
                success(data) {

                    $('.payment-form').addClass('d-none');
                    $('.checkCalc').closest('.modal-footer').addClass('d-none');

                    var htmlData = `
                     <ul class="list-group text-center">
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                            <img class="w-100"src="${data.gateway_image}"
                                style="max-width:100px; max-height:100px; margin:0 auto;"/>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                            @lang('Amount'):
                            <strong> ${data.amount} </strong>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Charge'):
                                <strong> ${data.charge}</strong>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                            @lang('Payable'): <strong> ${data.payable}</strong>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                            @lang('Conversion Rate'): <strong> ${data.conversion_rate}</strong>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-center align-items-start">
                            <strong> ${data.in}</strong>
                        </li>

                        ${(data.isCrypto == true) ? `
                        <li class="list-group-item border-0 d-flex justify-content-center align-items-start">
                            ${data.conversion_with}
                        </li>
                        ` : ``}

                        <li class="list-group-item border-0 d-flex justify-content-center align-items-start">
                        <a href="${data.payment_url}" class="btn-custom gradientBg addFund">@lang('Pay Now')</a>
                        </li>
                        </ul>`;

                    $('.payment-info').html(htmlData)
                },
                complete: function () {
                    $('#loading').hide();
                },
                error(err) {
                    var errors = err.responseJSON;
                    for (var obj in errors) {
                        $('.errors').text(`${errors[obj]}`)
                    }

                    $('.payment-form').removeClass('d-none');
                }
            });
        });


        $(document).on('click','.close', function (e) {
            $('#loading').hide();
            $('.payment-form').removeClass('d-none');
            $('.checkCalc').closest('.modal-footer').removeClass('d-none');
            $('.payment-info').html(``)
            $('.amount').val(``);
            $("#addFundModal").modal("hide");
        });

    </script>
@endpush

