@extends($theme.'layouts.user')
@section('title',trans($title))
@section('content')

    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang($title)</h2>
            </div>

            <div class="col-md-12">
                <!-- search area -->
                <div class="search-bar d-none d-lg-block">
                    <form action="{{ route('user.payout.history.search') }}" method="get">
                        <div class="row g-3 align-items-end">
                            <div class="input-box col-lg-3">
                                <input type="text" name="name" value="{{old('name',@request()->name)}}" class="form-control" placeholder="@lang('Search by Transaction ID')">
                            </div>

                            <div class="input-box col-lg-3">
                                <select name="status" class="form-select" aria-label="Default select example">
                                    <option value="">@lang('All Payment')</option>
                                    <option value="1"
                                            @if(@request()->status == '1') selected @endif>@lang('Pending Payment')</option>
                                    <option value="2"
                                            @if(@request()->status == '2') selected @endif>@lang('Completed Payment')</option>
                                    <option value="3"
                                            @if(@request()->status == '3') selected @endif>@lang('Rejected Payment')</option>
                                </select>
                            </div>

                            <div class="input-box col-lg-3">
                                <input type="date" class="form-control" name="date_time" value="{{old('date_time',@request()->date_time)}}"/>
                            </div>

                            <div class="input-box col-lg-3">
                                <button class="btn-custom w-100" type="submit">@lang('Search')</button>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- table -->
                <div class="mb-3">
                    <button
                    type="button"
                    class="btn-custom w-100 d-lg-none"
                    data-bs-toggle="modal"
                    data-bs-target="#addFundModal"
                    >
                    Filter <i class="fal fa-filter"></i>
                    </button>
                </div>
                <div class="table-parent table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th scope="col">@lang('Transaction ID')</th>
                                <th scope="col">@lang('Gateway')</th>
                                <th scope="col">@lang('Amount')</th>
                                <th scope="col">@lang('Charge')</th>
                                <th scope="col">@lang('Status')</th>
                                <th scope="col">@lang('Date-Time')</th>
                                <th scope="col">@lang('Details')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($payoutLog as $item)
                                <tr>
                                    <td data-label="#@lang('Transaction ID')">{{$item->trx_id}}</td>
                                    <td data-label="@lang('Gateway')">
                                        @lang(optional($item->method)->name)
                                        @if(optional($item->method)->is_automatic == 1)
                                            <sup class="greenColorText fw-bold">@lang('Automatic')</sup>
                                        @endif
                                    </td>
                                    <td data-label="@lang('Amount')">
                                        {{getAmount($item->amount)}} @lang($basic->currency)
                                    </td>
                                    <td data-label="@lang('Charge')">
                                        {{getAmount($item->charge)}} @lang($basic->currency)
                                    </td>

                                    <td data-label="@lang('Status')">
                                        @if($item->status == 1)
                                            <span class="badge bg-warning">@lang('Pending')</span>
                                        @elseif($item->status == 2)
                                            <span class="badge bg-primary">@lang('Completed')</span>
                                        @elseif($item->status == 3)
                                            <span class="badge bg-danger">@lang('Rejected')</span>
                                        @endif
                                    </td>

                                    <td data-label="@lang('Date-Time')">
                                        {{ dateTime($item->created_at, 'd M Y h:i A') }}
                                    </td>
                                    <td data-label="@lang('Details')">
                                        <button
                                            type="button" class="btn gradientBg btn-sm infoButton"
                                            data-information="{{json_encode($item->information)}}"
                                            data-feedback="{{$item->feedback}}"
                                            data-trx_id="{{ $item->trx_id }}"
                                            data-amount="{{ $item->amount }}"
                                            data-charge="{{ $item->charge }}"
                                            data-payable_amount="{{ $item->net_amount }}"
                                        >
                                            <i class="fa fa-info-circle"></i>
                                        </button>
                                    </td>

                                </tr>
                            @empty
                                <tr class="text-center">
                                    <td colspan="100%">{{trans('No Data Found!')}}</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div> <!-- table -->

                {{ $payoutLog->appends($_GET)->links($theme.'partials.pagination') }}

            </div>
        </div>
    </div>



    <div id="infoModal" class="modal fade" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content form-block text-white">
                <div class="modal-header">
                    <h4 class="modal-title">@lang('Details')</h4>
                    <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                        <i class="fal fa-times"></i>
                    </button>
                </div>
                <div class="modal-body">
                    <ul class="list-unstyled mb-3 text-dark">
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Amount') : <span class="amount"></span></li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Charge') : <span class="charge"></span></li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Payable Amount') : <span class="payable_amount"></span></li>

                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Transactions') : <span class="trx"></span>
                        </li>
                        <li class="list-group-item border-0 d-flex justify-content-between align-items-start">@lang('Admin Feedback') : <span class="feedback"></span></li>
                    </ul>

                    <div class="payout-detail">

                    </div>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                </div>
            </div>
        </div>
    </div>


    @push('loadModal')
        <div id="addFundModal" class="modal fade addFundModal" tabindex="-1" role="dialog" data-bs-backdrop="static">
            <div class="modal-dialog modal-dialog-centered modal-md">
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title method-name" id="editModalLabel">Search</h4>
                        <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>

                    <div class="modal-body">
                    <form action="{{ route('user.payout.history.search') }}" method="get">
                        <div class="row g-3 align-items-end">
                            <div class="input-box col-lg-3">
                                <input type="text" name="name" value="{{old('name',@request()->name)}}" class="form-control" placeholder="@lang('Search by Transaction ID')">
                            </div>

                            <div class="input-box col-lg-3">
                                <select name="status" class="form-select" aria-label="Default select example">
                                    <option value="">@lang('All Payment')</option>
                                    <option value="1"
                                            @if(@request()->status == '1') selected @endif>@lang('Pending Payment')</option>
                                    <option value="2"
                                            @if(@request()->status == '2') selected @endif>@lang('Completed Payment')</option>
                                    <option value="3"
                                            @if(@request()->status == '3') selected @endif>@lang('Rejected Payment')</option>
                                </select>
                            </div>

                            <div class="input-box col-lg-3">
                                <input type="date" class="form-control" name="date_time" value="{{old('date_time',@request()->date_time)}}"/>
                            </div>

                            <div class="input-box col-lg-3">
                                <button class="btn-custom w-100" type="submit">@lang('Search')</button>
                            </div>
                        </div>
                    </form>
                    </div>
                </div>
            </div>
        </div>
    @endpush

@endsection

@push('script')

    <script>
        "use strict";

        $(document).ready(function () {
            $('.infoButton').on('click', function () {
                var infoModal = $('#infoModal');
                infoModal.find('.trx').text($(this).data('trx_id'));
                infoModal.find('.feedback').text($(this).data('feedback'));
                infoModal.find('.amount').text($(this).data('amount') + " {{trans($basic->currency)}}");
                infoModal.find('.charge').text($(this).data('charge') + " {{trans($basic->currency)}}");
                infoModal.find('.payable_amount').text($(this).data('payable_amount') + " {{trans($basic->currency)}}");
                var list = [];
                var information = Object.entries($(this).data('information'));

                var ImgPath = "{{asset(config('location.withdrawLog.path'))}}";
                var result = ``;
                for (var i = 0; i < information.length; i++) {
                    if (information[i][1].type == 'file') {
                        result += `<li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                                        <span class="font-weight-bold "> ${information[i][0].replaceAll('_', " ")} </span> : <img class="w-100"src="${ImgPath}/${information[i][1].fieldValue}" alt="..." class="w-100">
                                    </li>`;
                    } else {
                        result += `<li class="list-group-item border-0 d-flex justify-content-between align-items-start">
                                        <span class="font-weight-bold "> ${information[i][0].replaceAll('_', " ")} </span> : <span class="font-weight-bold ml-3">${information[i][1].fieldValue}</span>
                                    </li>`;
                    }
                }

                if (result) {
                    infoModal.find('.payout-detail').html(`<br><strong class="my-3 font18 indegoTextColor">@lang('Payment Information')</strong>  ${result}`);
                } else {
                    infoModal.find('.payout-detail').html(`${result}`);
                }
                infoModal.modal('show');
            });


            $('.closeModal').on('click', function (e) {
                $("#infoModal").modal("hide");
            });
        });

    </script>
@endpush
