@extends($theme.'layouts.user')
@section('title', trans($title))

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang($title)</h2>
            </div>
            <div>
            <div class="row g-3 feature-wrapper top-0 add-fund">
                @foreach($gateways as $key => $gateway)
                    <div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 col-6">
                        <div class="card card-type-1 text-center bgGateway p-3">

                            <div class="card-icon">
                                <img class="w-100" src="{{ getFile(config('location.withdraw.path').$gateway->image)}}"
                                     alt="{{$gateway->name}}" >
                            </div>
                            <button type="button"
                                    data-id="{{$gateway->id}}"
                                    data-name="{{$gateway->name}}"
                                    data-min_amount="{{getAmount($gateway->minimum_amount, $basic->fraction_number)}}"
                                    data-max_amount="{{getAmount($gateway->maximum_amount,$basic->fraction_number)}}"
                                    data-percent_charge="{{getAmount($gateway->percent_charge,$basic->fraction_number)}}"
                                    data-fix_charge="{{getAmount($gateway->fixed_charge, $basic->fraction_number)}}"
                                    class="btn-custom addFund w-auto"
                                    data-bs-backdrop='static' data-keyboard='false'
                                    data-bs-toggle="modal" data-bs-target="#addFundModal">@lang('Withdraw Now')</button>

                        </div>
                    </div>
                @endforeach
            </div>
            </div>
        </div>
    </div>


    @push('loadModal')
        <div id="addFundModal" class="modal fade addFundModal" tabindex="-1" role="dialog" data-bs-backdrop="static">
            <div class="modal-dialog" role="document">
                <div class="modal-content form-block">
                    <div class="modal-header">
                        <h4 class="modal-title method-name"></h4>
                        <button type="button" class="close-btn close" data-bs-dismiss="modal" aria-label="Close">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>

                    <form action="{{route('user.payout.moneyRequest')}}" method="post">
                        @csrf
                        <div class="modal-body">
                            <div class="payment-form">
                                <p class="text-danger depositLimit fw-bold"></p>
                                <p class="text-danger depositCharge fw-bold"></p>
                                <input type="hidden" class="gateway" name="gateway" value="">

                                <div class="form-group">
                                    <label class="mb-1">@lang('Amount')</label>
                                    <div class="input-group input-box bg-transparent">
                                        <input type="text" class="amount form-control" name="amount" required placeholder="@lang('Enter Amount for Payout')" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')">
                                        <span class="input-group-text show-currency border-0"></span>
                                    </div>
                                    @error('amount')
                                        <p class="text-danger">{{$message}}</p>
                                    @enderror
                                </div>

                            </div>

                        </div>

                        <div class="modal-footer">
                            <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                            <button type="submit" class="btn-custom">@lang('Next')</button>
                        </div>

                    </form>

                </div>
            </div>
        </div>
    @endpush


@endsection



@push('script')

    @if(count($errors) > 0 )
        <script>
            @foreach($errors->all() as $key => $error)
            Notiflix.Notify.Failure("@lang($error)");
            @endforeach
        </script>
    @endif

    <script>
        "use strict";

        var id, minAmount, maxAmount, baseSymbol, fixCharge, percentCharge, currency, gateway;

        $(document).on('click', '.addFund',function () {
            id = $(this).data('id');
            gateway = $(this).data('gateway');
            minAmount = $(this).data('min_amount');
            maxAmount = $(this).data('max_amount');
            baseSymbol = "{{config('basic.currency_symbol')}}";
            fixCharge = $(this).data('fix_charge');
            percentCharge = $(this).data('percent_charge');
            currency = $(this).data('currency');
            $('.depositLimit').text(`@lang('Transaction Limit:') ${minAmount} - ${maxAmount}  ${baseSymbol}`);

            var depositCharge = `@lang('Charge:') ${fixCharge} ${baseSymbol}  ${(0 < percentCharge) ? ' + ' + percentCharge + ' % ' : ''}`;
            $('.depositCharge').text(depositCharge);
            $('.method-name').text(`@lang('Payout By') ${$(this).data('name')}`);
            $('.show-currency').text("{{config('basic.currency')}}");
            $('.gateway').val(id);
        });
        $(document).on('click', '.close',function (e) {
            $('#loading').hide();
            $('.amount').val(``);
            $("#addFundModal").modal("hide");
        });

    </script>
@endpush

