@extends($theme.'layouts.user')
@section('title',trans('Profile Settings'))

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="col">
                <!-- profile setting -->
                <section class="profile-setting">

                    <div class="row">
                        <div class="col">
                            <div class="header-text-full">
                                <h3>@lang('Profile Settings')</h3>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-lg-4 mb-4 mb-lg-0">
                            <div class="upload-img">
                                <form method="post" action="{{ route('user.updateProfile') }}" enctype="multipart/form-data">
                                    @csrf
                                    <div class="img-box">
                                        <input type="file" name="image" placeholder="@lang('Choose image')" id="image">
                                        <span class="select-file">@lang('Select Image')</span>
                                        <img class="w-100" id="image_preview_container" class="preview-image"
                                             src="{{getFile(config('location.user.path').$user->image)}}"
                                             alt="@lang('preview image')">
                                    </div>
                                    @error('image')
                                        <span class="text-danger">@lang($message)</span>
                                    @enderror

                                    <h5 class="p-0 m-0">@lang(ucfirst($user->fullname))</h5>
                                    <p class="p-0 my-1">@lang('Joined At') @lang($user->created_at->format('d M, Y g:i A'))</p>
                                    @if (isset(auth()->user()->provider) && auth()->user()->provider != Null)
                                        <button class="btn-custom w-100" disabled onclick="event.preventDefault();">@lang('Image Update')</button>
                                    @else
                                        <button type="submit" class="btn-custom w-100">@lang('Image Update')</button>
                                    @endif
                                </form>
                            </div>
                        </div>

                        <div class="col-lg-8">
                            <div class="edit-area">
                                <div class="profile-navigator">
                                    <button tab-id="ProfileInformation" class="golden-text tab {{ $errors->has('profile') ? 'active' : (($errors->has('password') || $errors->has('identity') || $errors->has('addressVerification')) ? '' : ' active') }}">
                                        @lang('Profile Information')
                                    </button>
                                    @if(!isset(auth()->user()->provider) && auth()->user()->provider == Null)
                                        <button tab-id="PasswordSetting" class="golden-text tab {{ $errors->has('password') ? 'active' : '' }}">
                                            @lang('Password Setting')
                                        </button>
                                    @endif
                                    <button tab-id="IdentityVerification" class="golden-text tab {{ $errors->has('identity') ? 'active' : '' }}">
                                        @lang('Identity Verification')
                                    </button>
                                    <button tab-id="AddressVerification" class="golden-text tab {{ $errors->has('addressVerification') ? 'active' : '' }}">
                                        @lang('Address Verification')
                                    </button>
                                </div>

                                <div id="ProfileInformation" class="content {{ $errors->has('profile') ? ' active' : (($errors->has('password') || $errors->has('identity') || $errors->has('addressVerification')) ? '' :  ' active') }}">
                                    <form action="{{ route('user.updateInformation')}}" method="post">
                                        @method('put')
                                        @csrf
                                        <div class="row">
                                            <div class="input-box col-md-6 mb-4">
                                                <label for="firstname" class="golden-text">@lang('First Name')</label>
                                                <input type="text" name="firstname" class="form-control" value="{{old('firstname') ?? $user->firstname }}" placeholder="@lang('Enter First Name')" />
                                                @if($errors->has('firstname'))
                                                    <div class="error text-danger">@lang($errors->first('firstname')) </div>
                                                @endif
                                            </div>

                                            <div class="input-box col-md-6 mb-4">
                                                <label for="lastname" class="golden-text">@lang('Last Name')</label>
                                                <input type="text" name="lastname" value="{{old('lastname') ?? $user->lastname }}" class="form-control" placeholder="@lang('Enter Last Name')" />
                                                @if($errors->has('lastname'))
                                                    <div class="error text-danger">@lang($errors->first('lastname')) </div>
                                                @endif
                                            </div>
                                            <div class="input-box col-md-6 mb-4">
                                                <label for="username" class="golden-text">@lang('Username')</label>
                                                <input type="text" name="username" value="{{old('username') ?? $user->username }}" class="form-control" placeholder="@lang('Enter Username')"/>
                                                @if($errors->has('username'))
                                                    <div class="error text-danger">@lang($errors->first('username')) </div>
                                                @endif
                                            </div>
                                            <div class="input-box col-md-6 mb-4">
                                                <label for="email" class="golden-text">@lang('Email Address')</label>
                                                <input type="email" value="{{ $user->email }}" readonly class="form-control" placeholder="@lang('Enter Email')"/>
                                                @if($errors->has('email'))
                                                    <div class="error text-danger">@lang($errors->first('email')) </div>
                                                @endif
                                            </div>

                                            @if(auth()->user()->phone == null)
                                                <div class="input-box col-md-6 mb-4">
                                                    @php
                                                        $country_code = (string) @getIpInfo()['code'] ?: null;
                                                        $myCollection = collect(config('country'))->map(function($row) {
                                                            return collect($row);
                                                        });
                                                        $countries = $myCollection->sortBy('code');
                                                    @endphp

                                                    <div class="input-group">
                                                        <label for="phone" class="golden-text d-block w-100">@lang('Phone Number')</label>
                                                        <div class="input-group-prepend w-50 d-block">
                                                            <select name="phone_code" class="form-control country_code dialCode-change" required>
                                                                @foreach(config('country') as $value)
                                                                    <option value="{{$value['phone_code']}}"
                                                                            data-name="{{$value['name']}}"
                                                                            data-code="{{$value['code']}}"
                                                                        {{$country_code == $value['code'] ? 'selected' : ''}}
                                                                    > {{$value['name']}} ({{$value['phone_code']}})

                                                                    </option>
                                                                @endforeach
                                                            </select>
                                                        </div>
                                                        <input type="text" name="phone" class="form-control dialcode-set ms-1" value="{{old('phone')}}" placeholder="@lang('Your Phone Number')" required>
                                                    </div>

                                                    @error('phone')
                                                        <span class="text-danger mt-1">@lang($message)</span>
                                                    @enderror

                                                    <input type="hidden" name="country_code" value="{{old('country_code')}}" class="text-dark">
                                                </div>
                                            @else
                                                <div class="input-box col-md-6 mb-4">
                                                    <label for="phone" class="golden-text">@lang('Phone Number')</label>
                                                    <input type="text" readonly value="{{$user->phone}}" class="form-control" placeholder="@lang('Enter Phone Number')"/>
                                                    @if($errors->has('phone'))
                                                        <div class="error text-danger">@lang($errors->first('phone')) </div>
                                                    @endif
                                                </div>
                                            @endif


                                            <div class="input-box col-md-6 mb-4">
                                                <label for="language_id" class="golden-text">@lang('Preferred language')</label>
                                                <select name="language_id" id="language_id" class="form-select" aria-label="Default select example">
                                                    <option value="" disabled>@lang('Select Language')</option>
                                                    @foreach($languages as $la)
                                                        <option value="{{$la->id}}" {{ old('language_id', $user->language_id) == $la->id ? 'selected' : '' }}>
                                                            @lang($la->name)
                                                        </option>
                                                    @endforeach
                                                </select>
                                                @if($errors->has('language_id'))
                                                    <div class="error text-danger">@lang($errors->first('language_id')) </div>
                                                @endif
                                            </div>
                                            <div class="input-box col-12 mb-4">
                                                <label for="address" class="golden-text">@lang('Address')</label>
                                                <textarea name="address" class="form-control" cols="30" rows="3" placeholder="@lang('Enter Address')">@lang($user->address)</textarea>
                                                @if($errors->has('address'))
                                                    <div class="error text-danger">@lang($errors->first('address')) </div>
                                                @endif
                                            </div>
                                        </div>
                                        <button type="submit" class="btn-custom w-100">@lang('Update User')</button>
                                    </form>
                                </div>


                                <div id="PasswordSetting" class="content {{ $errors->has('password') ? 'active' : '' }}">
                                    <form method="post" action="{{ route('user.updatePassword') }}">
                                        @csrf
                                        <div class="row">
                                            <div class="input-box col-md-6 mb-4">
                                                <label for="current_password" class="golden-text">@lang('Current Password')</label>
                                                <input id="current_password" type="password" class="form-control" name="current_password" autocomplete="off" placeholder="@lang('Enter Current Password')"/>
                                                @if($errors->has('current_password'))
                                                    <div class="error text-danger">@lang($errors->first('current_password')) </div>
                                                @endif
                                            </div>
                                            <div class="input-box col-md-6 mb-4">
                                                <label for="password" class="golden-text">@lang('New Password')</label>
                                                <input type="password" class="form-control" name="password" id="password" autocomplete="off" placeholder="@lang('Enter New Password')"/>
                                                @if($errors->has('password'))
                                                    <div class="error text-danger">@lang($errors->first('password')) </div>
                                                @endif
                                            </div>
                                            <div class="input-box col-12 mb-4">
                                                <label for="password_confirmation" class="golden-text">@lang('Confirm Password')</label>
                                                <input id="password_confirmation" type="password" name="password_confirmation" autocomplete="off" class="form-control" placeholder="@lang('Enter Confirm Password')">
                                                @if($errors->has('password_confirmation'))
                                                    <div class="error text-danger">@lang($errors->first('password_confirmation')) </div>
                                                @endif
                                            </div>
                                        </div>
                                        <button type="submit" class="btn-custom w-100">@lang('Update Password')</button>
                                    </form>
                                </div>


                                <div id="IdentityVerification" class="content {{ $errors->has('identity') ? 'active' : '' }}">
                                    @if(in_array($user->identity_verify,[0,3]))
                                        @if($user->identity_verify == 3)
                                            <div class="alert mb-0">
                                                <i class="fal fa-times-circle"></i>
                                                <span>@lang('You previous request has been rejected')</span>
                                            </div>
                                        @endif

                                        <form method="post" action="{{route('user.verificationSubmit')}}" enctype="multipart/form-data">
                                            @csrf
                                            <div class="input-box col-md-12 mb-4">
                                                <div class="form-group">
                                                    <label class="golden-text" for="identity_type">@lang('Identity Type')</label>
                                                    <select name="identity_type" id="identity_type" class="form-select" aria-label="Default select example">
                                                        <option value="" selected disabled>@lang('Select Type')</option>
                                                        @foreach($identityFormList as $sForm)
                                                            <option value="{{$sForm->slug}}" {{ old('identity_type', @$identity_type) == $sForm->slug ? 'selected' : '' }}>@lang($sForm->name)</option>
                                                        @endforeach
                                                    </select>
                                                    @error('identity_type')
                                                        <div class="error text-danger">@lang($message)</div>
                                                    @enderror
                                                </div>
                                            </div>
                                            @if(isset($identityForm))
                                                @foreach($identityForm->services_form as $k => $v)
                                                    @if($v->type == "text")
                                                        <div class="input-box col-md-12 mb-4">
                                                            <div class="form-group">
                                                                <label class="golden-text" for="{{$k}}">{{trans($v->field_level)}} @if($v->validation == 'required')
                                                                        <span class="text-danger">*</span>  @endif
                                                                </label>
                                                                <input type="text" name="{{$k}}"
                                                                       class="form-control "
                                                                       value="{{old($k)}}" id="{{$k}}"
                                                                       @if($v->validation == 'required') required @endif>

                                                                @if($errors->has($k))
                                                                    <div class="error text-danger">@lang($errors->first($k)) </div>
                                                                @endif
                                                            </div>
                                                        </div>
                                                    @elseif($v->type == "textarea")
                                                        <div class="input-box col-md-12 mb-4">
                                                            <div class="form-group">
                                                                <label class="golden-text" for="{{$k}}">{{trans($v->field_level)}} @if($v->validation == 'required')
                                                                        <span class="text-danger">*</span>  @endif
                                                                </label>
                                                                <textarea name="{{$k}}" id="{{$k}}"
                                                                          class="form-control "
                                                                          rows="5"
                                                                          placeholder="{{trans('Type Here')}}"
                                                                          @if($v->validation == 'required')@endif>{{old($k)}}</textarea>
                                                                @error($k)
                                                                    <div class="error text-danger">
                                                                        {{trans($message)}}
                                                                    </div>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    @elseif($v->type == "file")
                                                        <div class="input-box col-md-12 mb-4">
                                                            <div class="form-group">
                                                                <label class="golden-text">{{trans($v->field_level)}} @if($v->validation == 'required')
                                                                        <span class="text-danger">*</span>  @endif
                                                                </label>

                                                                <br>
                                                                <div class="fileinput fileinput-new "
                                                                     data-provides="fileinput">
                                                                    <div class="fileinput-new thumbnail "
                                                                         data-trigger="fileinput">
                                                                        <img class="w-150px "
                                                                             src="{{ getFile(config('location.default')) }}"
                                                                             alt="...">
                                                                    </div>
                                                                    <div class="fileinput-preview fileinput-exists thumbnail wh-200-150"></div>

                                                                    <div class="img-input-div">
                                                                    <span class="btn gradientBg btn-file">
                                                                        <span class="fileinput-new"> @lang('Select') {{$v->field_level}}</span>
                                                                        <span class="fileinput-exists"> @lang('Change')</span>
                                                                        <input type="file" name="{{$k}}"
                                                                               value="{{ old($k) }}" accept="image/*"
                                                                               @if($v->validation == "required")@endif>
                                                                    </span>
                                                                        <a href="#" class="btn btn-danger fileinput-exists" data-dismiss="fileinput"> @lang('Remove')</a>
                                                                    </div>

                                                                </div>

                                                                @error($k)
                                                                    <div class="error text-danger">
                                                                        {{trans($message)}}
                                                                    </div>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    @endif

                                                @endforeach

                                                <button type="submit" class="btn-custom w-100">@lang('Submit')</button>
                                            @endif
                                        </form>

                                    @elseif($user->identity_verify == 1)
                                        <div class="alert mb-0">
                                            <i class="fal fa-undo"></i>
                                            <span>@lang('Your Identity Verification submission has been Pending.')</span>
                                        </div>
                                    @elseif($user->identity_verify == 2)
                                        <div class="alert mb-0">
                                            <i class="fal fa-check-circle"></i>
                                            <span>@lang('Your Identity Verification has already Verified.')</span>
                                        </div>
                                    @endif

                                </div>


                                <div id="AddressVerification" class="content {{ $errors->has('addressVerification') ? 'active' : '' }}">
                                    @if(in_array($user->address_verify,[0,3]))
                                        @if($user->address_verify == 3)
                                            <div class="alert mb-0">
                                                <i class="fal fa-times-circle"></i>
                                                <span>@lang('You previous request has been rejected')</span>
                                            </div>
                                        @endif

                                        <form method="post" action="{{route('user.addressVerification')}}" enctype="multipart/form-data">
                                            @csrf
                                            <div class="input-box col-md-12 mb-4">
                                                <div class="form-group">
                                                    <label class="golden-text">{{trans('Address Proof')}} <span class="text-danger">*</span> </label><br>

                                                    <div class="fileinput fileinput-new "
                                                         data-provides="fileinput">
                                                        <div class="fileinput-new thumbnail "
                                                             data-trigger="fileinput">
                                                            <img class="w-150px "
                                                                src="{{ getFile(config('location.default')) }}"
                                                                alt="...">
                                                        </div>
                                                        <div class="fileinput-preview fileinput-exists thumbnail wh-200-150"></div>

                                                        <div class="img-input-div">
                                                                    <span class="btn gradientBg btn-file">
                                                                        <span
                                                                            class="fileinput-new "> @lang('Select Image') </span>
                                                                        <span
                                                                            class="fileinput-exists"> @lang('Change')</span>
                                                                        <input type="file" name="addressProof"
                                                                               value="{{ old('addressProof')}}"
                                                                               accept="image/*">
                                                                    </span>
                                                            <a href="#" class="btn btn-danger fileinput-exists"
                                                               data-dismiss="fileinput"> @lang('Remove')</a>
                                                        </div>

                                                    </div>

                                                    @error('addressProof')
                                                        <div class="error text-danger">
                                                            {{trans($message)}}
                                                        </div>
                                                    @enderror
                                                </div>
                                            </div>

                                            <button type="submit" class="btn-custom w-100">@lang('Submit')</button>
                                        </form>

                                    @elseif($user->address_verify == 1)
                                        <div class="alert mb-0">
                                            <i class="fal fa-undo"></i>
                                            <span>@lang('Your Address Verification submission has been Pending.')</span>
                                        </div>
                                    @elseif($user->address_verify == 2)
                                        <div class="alert mb-0">
                                            <i class="fal fa-check-circle"></i>
                                            <span>@lang('Your Address Verification has already Verified.')</span>
                                        </div>
                                    @endif
                                </div>

                            </div>
                        </div>
                    </div>
                </section>
            </div>
        </div>
    </div>
@endsection

@push('css-lib')
    <link rel="stylesheet" href="{{asset($themeTrue.'css/bootstrap-fileinput.css')}}">
@endpush

@push('extra-js')
    <script src="{{asset($themeTrue.'js/bootstrap-fileinput.js')}}"></script>
@endpush

@push('script')
    <script>
        "use strict";
        var isCurrntUserBySocialLogin = "{{auth()->user()->provider}}"

        $(document).on('click', '#image-label', function () {
            if (isCurrntUserBySocialLogin) {
                Notiflix.Notify.Failure("Because of using social login you can't change image");
            } else {
                $('#image').trigger('click');
            }
        });
        $(document).on('change', '#image', function () {
            if (isCurrntUserBySocialLogin) {
                Notiflix.Notify.Failure("Because of using social login you can't change image");
            } else {
                var _this = $(this);
                var newimage = new FileReader();
                newimage.readAsDataURL(this.files[0]);
                newimage.onload = function (e) {
                    $('#image_preview_container').attr('src', e.target.result);
                }
            }

        });

        $(document).on('change', "#identity_type", function () {
            let value = $(this).find('option:selected').val();
            window.location.href = "{{route('user.profile')}}/?identity_type=" + value
        });

        $(document).ready(function () {
            setDialCode();
            $(document).on('change', '.dialCode-change', function () {
                setDialCode();
            });
            function setDialCode() {
                let currency = $('.dialCode-change').val();
                $('.dialcode-set').val(currency);
            }
        });

        var getTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;
        $('.timeZone').val(getTimeZone);
    </script>
@endpush
