@extends($theme.'layouts.user')
@section('title')
    @lang('Create Advertisement')
@endsection

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang('Create Advertisement')</h2>
                <a href="{{ route('user.all.advertise') }}" class="btn-custom">
                    <i class="far fa-list"></i>@lang('All Advertise List')
                </a>
            </div>
            <div class="profile-setting col-12">
                <div class="edit-area">
                    <pre class="text-danger mb-4">@lang('*NB: ')<span class="price-per-ad"></span> {{ $basic->currency }} @lang('is charged for each advertisement.')</pre>
                    <form role="form" method="POST" action="{{ route("user.my.advertise.store") }}" enctype="multipart/form-data">
                        @csrf
                        <div class="row g-4">
                            <div class="input-box col-md-12">
                                <label for="ads_name">@lang('Advertise Name') <span class="text-danger">*</span></label>
                                <input type="text" name="ads_name" class="form-control" value="{{ old('ads_name') }}" required placeholder="@lang('Enter Advertise Name')" id="ads_name"/>
                                @error('ads_name')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-md-4">
                                <label for="ads_type">@lang('Advertisement Type') <span class="text-danger">*</span></label>
                                <select name="ads_type" required class="form-select" id="ads_type">
                                    <option value="1" {{ old('ads_type') == 1 ? 'selected' : '' }}>@lang('URL/Link')</option>
                                    <option value="4" {{ old('ads_type') == 4 ? 'selected' : '' }}>@lang('Code/Script')</option>
                                    <option value="3" {{ old('ads_type') == 3 ? 'selected' : '' }}>@lang('Picture/Banner')</option>
                                    <option value="2" {{ old('ads_type') == 2 ? 'selected' : '' }}>@lang('Youtube Embeded Link')</option>
                                </select>
                                @error('ads_type')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>


                            <div class="input-box col-md-8" id="websiteLink">
                                <label>@lang('URL/Link') <span class="text-danger">*</span></label>
                                <input type="url" class="form-control" value="{{ old('website_link') }}" name="website_link" placeholder="@lang('http://example.com')"/>
                                @error('website_link')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>
                            <div class="input-box col-md-8" id="youtube">
                                <label>@lang('Youtube Embeded Link') <span class="text-danger">*</span></label>
                                <input type="text" class="form-control" name="youtube" value="{{ old('youtube') }}" placeholder="@lang('Enter youtube embed link')"/>
                                @error('youtube')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>
                            <div class="input-box col-md-8" id="bannerImage">
                                <label>@lang('Picture/Banner') <span class="text-danger">*</span></label>
                                <div class="attach-file">
                                    <span class="prev">@lang('choose file')</span>
                                    <input class="form-control" name="banner_image" accept="image/*" type="file"/>
                                </div>
                                @error('banner_image')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>
                            <div class="input-box col-md-8" id="script">
                                <label>@lang('Script/Code') <span class="text-danger">*</span></label>
                                <textarea
                                    class="form-control"
                                    name="script"
                                    cols="30"
                                    rows="3"
                                    placeholder="@lang('Enter Script/Code')"
                                ></textarea>
                                @error('script')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-md-6">
                                <label for="ads_duration">@lang('Advertisement Duration') <span class="text-danger">*</span></label>
                                <div class="input-group">
                                    <input type="text" name="ads_duration" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('ads_duration') }}" required placeholder="@lang('Enter advertisement duration')">
                                    <span class="input-group-text gradientBg border-0">@lang('Seconds')</span>
                                </div>
                                @error('ads_duration')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-md-6">
                                <label for="max_show_limit">@lang('Maximum Show Limit') <span class="text-danger">*</span></label>
                                <div class="input-group">
                                    <input type="text" name="max_show_limit" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('max_show_limit') }}" required placeholder="@lang('Enter maximum show limit')">
                                    <span class="input-group-text gradientBg border-0">@lang('Times')</span>
                                </div>
                                <pre class="text-danger"><span class="total-price"></span> {{ $basic->currency }} @lang('will deduct from your fund balance')</pre>
                                @error('max_show_limit')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-12">
                                <button type="submit" class="btn-custom w-100">@lang('submit')</button>
                            </div>

                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

@endsection


@push('script')
    <script>
        (function($){
            "use strict";

            var price = 0;

            $('#ads_type').change(function(){
                var adsType = $(this).val();
                if (adsType == 1) {
                    $("#websiteLink").removeClass('d-none');
                    $("#bannerImage").addClass('d-none');
                    $("#script").addClass('d-none');
                    $("#youtube").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->url }}
                } else if (adsType == 2) {
                    $("#youtube").removeClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#script").addClass('d-none');
                    $("#bannerImage").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->youtube ?? 0}}
                } else if(adsType == 3) {
                    $("#script").addClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#bannerImage").removeClass('d-none');
                    $("#youtube").addClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->image }}
                } else {
                    $("#bannerImage").addClass('d-none');
                    $("#websiteLink").addClass('d-none');
                    $("#youtube").addClass('d-none');
                    $("#script").removeClass('d-none');
                    price = {{ @$siteConfigure->ads_setting->ad_price->script }}
                }

                $('.price-per-ad').text(price);

                $('[name=max_show_limit]').trigger('input');

            }).change();


            $('[name=max_show_limit]').on('input', function () {
                var maxShow = $(this).val();
                var totalPrice = price * maxShow;
                $('.total-price').text(totalPrice);
            });

        })(jQuery);
    </script>
@endpush
