@extends($theme.'layouts.user')
@section('title')
    @lang('Edit Advertisement')
@endsection

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang('Edit Advertisement')</h2>
                <a href="{{ route('user.my.advertise') }}" class="btn-custom">
                    @lang('My Advertisement')
                </a>
            </div>
            <div class="profile-setting col-12">
                <div class="edit-area">
                    <form role="form" method="POST" action="{{ route("user.update.my.ad", $myAdvertise->id) }}" enctype="multipart/form-data">
                        @csrf
                        <div class="row g-4">
                            <div class="input-box col-md-6">
                                <label for="ads_name">@lang('Advertise Name') <span class="text-danger">*</span></label>
                                <input type="text" name="ads_name" class="form-control" value="{{ old('ads_name', $myAdvertise->ads_name) }}" required placeholder="@lang('Enter Advertise Name')" id="ads_name"/>
                                @error('ads_name')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-md-6">
                                <label for="ads_duration">@lang('Advertisement Duration') <span class="text-danger">*</span></label>
                                <div class="input-group">
                                    <input type="text" name="ads_duration" onkeyup="this.value = this.value.replace (/^\.|[^\d\.]/g, '')" class="form-control" value="{{ old('ads_duration', $myAdvertise->ads_duration) }}" required>
                                    <span class="input-group-text gradientBg border-0">@lang('Seconds')</span>
                                </div>
                                @error('ads_duration')
                                    <span class="text-danger">@lang($message)</span>
                                @enderror
                            </div>

                            <div class="input-box col-md-3">
                                <label for="ads_type">@lang('Advertisement Type') <span class="text-danger">*</span></label>
                                <input type="hidden" name="ads_type" value="{{ old('ads_type', $myAdvertise->ads_type)}}">
                                <div class="pt-1 previewAd cursorPointer">
                                    @if($myAdvertise->ads_type == 1)
                                        <span class="badge bg-primary adCategory"
                                            data-adlink="{{ $myAdvertise->ads_body }}"
                                            data-adtype="{{ $myAdvertise->ads_type }}"
                                        >
                                            @lang('URL/Link')
                                        </span>
                                    @elseif($myAdvertise->ads_type == 2)
                                        <span class="badge bg-danger adCategory"
                                            data-adlink="{{ $myAdvertise->ads_body }}"
                                            data-adtype="{{ $myAdvertise->ads_type }}"
                                        >
                                            @lang('Youtube Embeded Link')
                                        </span>
                                    @elseif($myAdvertise->ads_type == 3)
                                        <span class="badge bg-secondary adCategory"
                                            data-adlink="{{ $myAdvertise->ads_body }}"
                                            data-adtype="{{ $myAdvertise->ads_type }}"
                                        >
                                            @lang('Picture/Banner')
                                        </span>
                                    @elseif($myAdvertise->ads_type == 4)
                                        <span class="badge bg-info adCategory"
                                            data-adlink="{{ $myAdvertise->ads_body }}"
                                            data-adtype="{{ $myAdvertise->ads_type }}"
                                        >
                                            @lang('Code/Script')
                                        </span>
                                    @endif
                                </div>
                            </div>


                            @if ($myAdvertise->ads_type == 1)
                                <div class="input-box col-md-9">
                                    <label>@lang('URL/Link') <span class="text-danger">*</span></label>
                                    <input type="url" class="form-control" value="{{ old('website_link', $myAdvertise->ads_body) }}" name="website_link" placeholder="@lang('http://example.com')" required/>
                                    @error('website_link')
                                        <span class="text-danger">@lang($message)</span>
                                    @enderror
                                </div>
                            @elseif ($myAdvertise->ads_type == 4)
                                <div class="input-box col-md-9">
                                    <label>@lang('Script/Code') <span class="text-danger">*</span></label>
                                    <textarea
                                        class="form-control"
                                        name="script"
                                        cols="30"
                                        rows="3"
                                        placeholder="@lang('Enter Script/Code')"
                                        required
                                    >{{$myAdvertise->ads_body}}</textarea>
                                    @error('script')
                                        <span class="text-danger">@lang($message)</span>
                                    @enderror
                                </div>
                            @elseif ($myAdvertise->ads_type == 3)
                                <div class="input-box col-md-5">
                                    <label>@lang('Picture/Banner') <span class="text-danger">*</span></label>
                                    <div class="attach-file">
                                        <span class="prev">@lang('choose file')</span>
                                        <input class="form-control" name="banner_image" accept="image/*" type="file"/>
                                    </div>
                                    @error('banner_image')
                                        <span class="text-danger">@lang($message)</span>
                                    @enderror
                                </div>
                                <div class="input-box col-md-4">
                                    <label>@lang('Current Existing Picture/Banner :')</label>
                                    <img class="w-100" src="{{ getFile(config('location.advertisement.path').$myAdvertise->ads_body) }}">
                                </div>
                            @elseif ($myAdvertise->ads_type == 2)
                                <div class="input-box col-md-9">
                                    <label>@lang('Youtube Embeded Link') <span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" name="youtube" value="{{ old('youtube', $myAdvertise->ads_body) }}" required placeholder="@lang('Enter youtube embed link')"/>
                                    @error('youtube')
                                        <span class="text-danger">@lang($message)</span>
                                    @enderror
                                </div>
                            @endif

                            <div class="input-box col-12">
                                <button type="submit" class="btn-custom w-100">@lang('submit')</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>


    <!-- Preview Modal -->
    <div id="adPreview" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog modal-dialog-centered modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title method-name" id="editModalLabel">@lang('Preview Advertisement')</h4>
                    <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                        <i class="fal fa-times"></i>
                    </button>
                </div>

                <div class="modal-body">
                    <iframe src=""
                        title="@lang('iframe ad preview')"
                        class="iframeAdView preview-type type-1 d-none"
                    >
                    </iframe>
                    <div class="youtubeEmbedLink preview-type type-2 d-none"></div>
                    <img src="" class="imgAdPreview preview-type type-3 d-none" width="768px" height="512px" alt="@lang('img ad preview')">
                    <div class="scriptPreview preview-type type-4 d-none"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                </div>

            </div>
        </div>
    </div>

@endsection


@push('script')
    <script>
        'use strict';
        (function($){
            $(document).on('click','.adCategory', function() {
                var adLink = $(this).data('adlink');
                var adType = $(this).data('adtype');

                var modal = $('#adPreview');

                if (adType == 1) {
                    modal.find(`.type-${adType}`).attr('src', adLink);
                }
                else if(adType == 2){
                    modal.find(`.type-${adType}`).html(`${adLink}`);
                    $("div.youtubeEmbedLink").find("iframe").height('450px');
                    $("div.youtubeEmbedLink").find("iframe").width('100%');
                }
                else if(adType == 3){
                    var imgPath = "{{asset(config('location.advertisement.path'))}}"
                    var imgLink = imgPath+'/'+`${adLink}`;
                    modal.find(`.type-${adType}`).attr('src', imgLink);
                }
                else if(adType == 4){
                    modal.find(`.type-${adType}`).html(`<pre><code>${adLink}</code></pre>`);
                }

                $(`.type-${adType}`).removeClass('d-none');
                $(".preview-type").not(`.type-${adType}`).addClass('d-none');

                modal.modal('show');
            });
        })(jQuery);
    </script>

    @if ($errors->any())
        @php
            $collection = collect($errors->all());
            $errors = $collection->unique();
        @endphp

        <script>
            "use strict";
            @foreach ($errors as $error)
                Notiflix.Notify.Failure("{{trans($error)}}");
            @endforeach
        </script>
    @endif

@endpush
