@extends($theme.'layouts.user')
@section('title',trans('Deposit History'))

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="dashboard-heading">
                <h2 class="mb-0">@lang('Deposit History')</h2>
            </div>

            <div class="col-12">
                <!-- search area -->
                <div class="search-bar d-none d-lg-block">
                    <form action="{{ route('user.fund-history.search') }}" method="get">
                        <div class="row g-3 align-items-end">
                            <div class="input-box col-lg-3">
                                <input type="text" name="name" value="{{old('name',@request()->name)}}" class="form-control" placeholder="@lang('Search by Transaction ID')">
                            </div>

                            <div class="input-box col-lg-3">
                                <select name="status" class="form-select" aria-label="Default select example">
                                    <option value="">@lang('All Payment')</option>
                                    <option value="1"
                                            @if(@request()->status == '1') selected @endif>@lang('Complete Payment')</option>
                                    <option value="2"
                                            @if(@request()->status == '2') selected @endif>@lang('Pending Payment')</option>
                                    <option value="3"
                                            @if(@request()->status == '3') selected @endif>@lang('Cancel Payment')</option>
                                </select>
                            </div>

                            <div class="input-box col-lg-3">
                                <input type="date" class="form-control" name="date_time" value="{{old('date_time',@request()->date_time)}}"/>
                            </div>

                            <div class="input-box col-lg-3">
                                <button class="btn-custom w-100" type="submit">@lang('Search')</button>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- table -->
                <div class="mb-3">
                    <button
                    type="button"
                    class="btn-custom w-100 d-lg-none"
                    data-bs-toggle="modal"
                    data-bs-target="#addFundModal"
                    >
                    Filter <i class="fal fa-filter"></i>
                    </button>
                </div>
                <div class="table-parent table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th scope="col">@lang('Transaction ID')</th>
                                <th scope="col">@lang('Gateway')</th>
                                <th scope="col">@lang('Amount')</th>
                                <th scope="col">@lang('Charge')</th>
                                <th scope="col">@lang('Status')</th>
                                <th scope="col">@lang('Date-Time')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($funds as $data)
                            <tr>
                                <td data-label="@lang('Transaction ID')">{{$data->transaction}}</td>
                                <td data-label="@lang('Gateway')">@lang(optional($data->gateway)->name)</td>
                                <td data-label="@lang('Amount')">
                                    <strong>{{getAmount($data->amount)}} @lang($basic->currency)</strong>
                                </td>

                                <td data-label="@lang('Charge')">
                                    <span>{{getAmount($data->charge)}} @lang($basic->currency)</span>
                                </td>

                                <td data-label="@lang('Status')">
                                    @if($data->status == 1)
                                        <span class="badge bg-primary">@lang('Completed')</span>
                                    @elseif($data->status == 2)
                                        <span class="badge bg-warning">@lang('Pending')</span>
                                    @elseif($data->status == 3)
                                        <span class="badge bg-danger">@lang('Canceled')</span>
                                    @endif
                                </td>

                                <td data-label="@lang('Date-Time')">
                                    {{ dateTime($data->created_at, 'd M Y h:i A') }}
                                </td>
                            </tr>
                            @empty
                                <tr class="text-center">
                                    <td colspan="100%">{{__('No Data Found!')}}</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div> <!-- table -->

                {{ $funds->appends($_GET)->links($theme.'partials.pagination') }}

            </div>
        </div>
    </div>

    @push('loadModal')
        <div id="addFundModal" class="modal fade addFundModal" tabindex="-1" role="dialog" data-bs-backdrop="static">
            <div class="modal-dialog modal-dialog-centered modal-md">
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title method-name" id="editModalLabel">Search</h4>
                        <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>

                    <div class="modal-body">
                        <form action="{{ route('user.fund-history.search') }}" method="get">
                            <div class="row g-3 align-items-end">
                                <div class="input-box col-lg-3">
                                    <input type="text" name="name" value="{{old('name',@request()->name)}}" class="form-control" placeholder="@lang('Search by Transaction ID')">
                                </div>

                                <div class="input-box col-lg-3">
                                    <select name="status" class="form-select" aria-label="Default select example">
                                        <option value="">@lang('All Payment')</option>
                                        <option value="1"
                                                @if(@request()->status == '1') selected @endif>@lang('Complete Payment')</option>
                                        <option value="2"
                                                @if(@request()->status == '2') selected @endif>@lang('Pending Payment')</option>
                                        <option value="3"
                                                @if(@request()->status == '3') selected @endif>@lang('Cancel Payment')</option>
                                    </select>
                                </div>

                                <div class="input-box col-lg-3">
                                    <input type="date" class="form-control" name="date_time" value="{{old('date_time',@request()->date_time)}}"/>
                                </div>

                                <div class="input-box col-lg-3">
                                    <button class="btn-custom w-100" type="submit">@lang('Search')</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    @endpush

@endsection

