@extends($theme.'layouts.user')
@section('title',__('2 Step Security'))

@section('content')
    <div class="container-fluid">
        <div class="main row">
            <div class="col">
                <div class="dashboard-heading">
                    <h2 class="mb-0">@lang('2 Step Security')</h2>
                </div>
            </div>
            <div class="col-12">
                <section class="p-0">
                    <div class="row g-4">
                        @if(auth()->user()->two_fa)
                            <div class="col-lg-6">
                                <div class="cardDesign input-box w-100">
                                    <h4 class="title mb-4 mx-4 mt-2 text-center">@lang('Two Factor Authenticator')</h4>
                                    <div class="input-group my-4">
                                        <input type="text" value="{{$secret}}" class="form-control form-control-lg" id="referralURL" readonly>
                                        <span class="input-group-text copytext gradientBg border-0 cursorPointer" id="copyBoard" onclick="copyFunction()">
                                            <i class="fa fa-copy"></i>
                                        </span>
                                    </div>

                                    <div class="form-group  text-center">
                                        <img class="w-50"  src="{{$qrCodeUrl}}">
                                    </div>

                                    <div class="form-group mx-auto text-center mt-4">
                                        <a href="javascript:void(0)" class="btn-custom w-auto"
                                        data-bs-toggle="modal" data-bs-target="#disableModal">@lang('Disable Two Factor')</a>
                                    </div>

                                </div>
                            </div>
                        @else
                            <div class="col-lg-6">
                                <div class="cardDesign input-box ">
                                    <h4 class="title mb-4 mx-4 mt-2 text-center">@lang('Two Factor Authenticator')</h4>
                                    <div class="input-group my-4 ">
                                        <input type="text" value="{{$secret}}" class="form-control form-control-lg " id="referralURL" readonly>

                                        <span class="input-group-text copytext gradientBg border-0 cursorPointer" id="copyBoard" onclick="copyFunction()">
                                            <i class="fa fa-copy"></i>
                                        </span>
                                    </div>

                                    <div class="form-group  text-center">
                                        <img class="w-25" src="{{$qrCodeUrl}}">
                                    </div>

                                    <div class="form-group mx-auto text-center mt-4">
                                        <a href="javascript:void(0)" class="btn-custom w-auto"
                                        data-bs-toggle="modal" data-bs-target="#enableModal">@lang('Enable Two Factor')</a>
                                    </div>

                                </div>
                            </div>
                        @endif


                        <div class="col-lg-6">
                            <div class="cardDesign w-100 text-center">
                                <h4 class="title mb-4 mx-4 mt-2 ">@lang('Google Authenticator')</h4>
                                <div class="mt-5">
                                    <h5 class="text-uppercase my-3 ">
                                        @lang('Use Google Authenticator to Scan the QR code  or use the code')
                                    </h5>

                                    <p class="mx-3">@lang('Google Authenticator is a multifactor app for mobile devices. It generates timed codes used during the 2-step verification process. To use Google Authenticator, install the Google Authenticator application on your mobile device.')</p>
                                    <a class="btn-custom w-auto mt-3"
                                       href="https://play.google.com/store/apps/details?id=com.google.android.apps.authenticator2&hl=en"
                                       target="_blank">@lang('DOWNLOAD APP')</a>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
            </div>
        </div>
    </div>


    <!--Enable Modal -->
    <div id="enableModal" class="modal fade" role="dialog">
        <div class="modal-dialog">

            <!-- Modal content-->
            <div class="modal-content form-block">
                <div class="modal-header">
                    <h4 class="modal-title">@lang('Verify Your OTP')</h4>
                    <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                        <i class="fal fa-times"></i>
                    </button>
                </div>
                <form action="{{route('user.twoStepEnable')}}" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="input-box">
                            <input type="hidden" name="key" value="{{$secret}}">
                            <input type="text" class="form-control" name="code" required placeholder="@lang('Enter Google Authenticator Code')">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn-custom">@lang('Verify')</button>
                    </div>

                </form>
            </div>

        </div>
    </div>

    <!--Disable Modal -->
    <div id="disableModal" class="modal fade" role="dialog">
        <div class="modal-dialog">

            <!-- Modal content-->
            <div class="modal-content form-block">
                <div class="modal-header">
                    <h4 class="modal-title">@lang('Verify Your OTP to Disable')</h4>
                    <button type="button" class="close-btn" data-bs-dismiss="modal" aria-label="Close">
                        <i class="fal fa-times"></i>
                    </button>
                </div>
                <form action="{{route('user.twoStepDisable')}}" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="input-box">
                            <input type="text" class="form-control" name="code" required placeholder="@lang('Enter Google Authenticator Code')">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn-custom close-btn" data-bs-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn-custom">@lang('Verify')</button>
                    </div>
                </form>
            </div>

        </div>
    </div>

@endsection



@push('script')
    <script>
        function copyFunction() {
            var copyText = document.getElementById("referralURL");
            copyText.select();
            copyText.setSelectionRange(0, 99999);
            /*For mobile devices*/
            document.execCommand("copy");
            Notiflix.Notify.Success(`Copied: ${copyText.value}`);
        }
    </script>


    @if ($errors->any())
        @php
            $collection = collect($errors->all());
            $errors = $collection->unique();
        @endphp

        <script>
            "use strict";
            @foreach ($errors as $error)
                Notiflix.Notify.Failure("{{trans($error)}}");
            @endforeach
        </script>
    @endif
@endpush

