<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Artisan;

Route::get('/clear', function () {

    $output = new \Symfony\Component\Console\Output\BufferedOutput();
    Artisan::call('optimize:clear', array(), $output);
    return $output->fetch();
})->name('/clear');


Route::get('/user', 'Auth\LoginController@showLoginForm')->name('login');
Route::post('/loginModal', 'Auth\LoginController@loginModal')->name('loginModal');

Route::get('queue-work', function () {
    return Illuminate\Support\Facades\Artisan::call('queue:work', ['--stop-when-empty' => true]);
})->name('queue.work');


Auth::routes(['verify' => true]);

Route::group(['middleware' => ['guest']], function () {
    Route::get('register/{sponsor?}', 'Auth\RegisterController@sponsor')->name('register.sponsor');
});

Route::group(['middleware' => ['auth'], 'prefix' => 'user', 'as' => 'user.'], function () {
    Route::get('/check', 'User\VerificationController@check')->name('check');
    Route::get('/resend_code', 'User\VerificationController@resendCode')->name('resendCode');
    Route::post('/mail-verify', 'User\VerificationController@mailVerify')->name('mailVerify');
    Route::post('/sms-verify', 'User\VerificationController@smsVerify')->name('smsVerify');
    Route::post('twoFA-Verify', 'User\VerificationController@twoFAverify')->name('twoFA-Verify');
    Route::middleware('userCheck')->group(function () {

       Route::middleware('kyc')->group(function () {

            Route::get('/dashboard', 'User\HomeController@index')->name('home');


            // plan purchase
            Route::post('/purchase/plan', 'User\HomeController@purchasePlan')->name('purchase-plan');
            Route::get('/purchase/plan/history', 'User\HomeController@purchasedPlanHistory')->name('plan.purchased.log');
            Route::get('/purchase/plan/history/search', 'User\HomeController@purchasedPlanHistorySearch')->name('plan.purchased.log.search');

            // PTC Advertisement
            Route::get('/all/advertisement', 'User\PtcManageController@allAdvertise')->name('all.advertise');
            Route::get('/create/advertisement', 'User\PtcManageController@createAdvertise')->name('create.advertise');
            Route::post('/create/my/advertisement', 'User\PtcManageController@storeMyAdvertise')->name('my.advertise.store');

            Route::get('/my/advertisement', 'User\PtcManageController@myAdvertise')->name('my.advertise');
            Route::get('search/my/advertisement', 'User\PtcManageController@searchMyAdvertise')->name('search.my.advertise');

            Route::get('edit/my/advertisement/{id}', 'User\PtcManageController@editMyAdvertise')->name('edit.my.ad');
            Route::post('update/my/advertisement/{id}', 'User\PtcManageController@updateMyAdvertise')->name('update.my.ad');

            Route::put('/active/my/advertisement/{id}', 'User\PtcManageController@activeMyAdvertise')->name('ad.status.active');
            Route::put('/deactive/my/advertisement/{id}', 'User\PtcManageController@deactiveMyAdvertise')->name('ad.status.deactive');

            Route::get('/advertisement/view/{hashId}', 'User\PtcManageController@viewAdvertise')->name('advertise.view');
            Route::post('/advertisement/view/successfull/{hashId}', 'User\PtcManageController@submitViewAdvertise')->name('advertise.view.successful');

            Route::get('/total/clicks/earnings', 'User\PtcManageController@totalClickEarnings')->name('all.click.earnings');
            Route::get('/total/clicks/earnings/search', 'User\PtcManageController@searchClickEarnings')->name('search.click.earnings');


            // Money/fund-transfer
            Route::get('/money-transfer', 'User\HomeController@moneyTransfer')->name('money-transfer');
            Route::post('/money-transfer', 'User\HomeController@moneyTransferConfirm')->name('money.transfer');


            // Add-Fund/Deposit
            Route::get('add-fund', 'User\HomeController@addFund')->name('addFund');
            Route::post('add-fund', 'PaymentController@addFundRequest')->name('addFund.request');
            Route::get('addFundConfirm', 'PaymentController@depositConfirm')->name('addFund.confirm');
            Route::post('addFundConfirm', 'PaymentController@fromSubmit')->name('addFund.fromSubmit');

            // Fund/Deposit history
            Route::get('deposit-history', 'User\HomeController@fundHistory')->name('fund-history');
            Route::get('deposit-history-search', 'User\HomeController@fundHistorySearch')->name('fund-history.search');


            //transaction
            Route::get('/transaction', 'User\HomeController@transaction')->name('transaction');
            Route::get('/transaction-search', 'User\HomeController@transactionSearch')->name('transaction.search');

            // Referral
            Route::get('/referral', 'User\HomeController@referral')->name('referral');
            Route::get('/referral-bonus', 'User\HomeController@referralBonus')->name('referral.bonus');
            Route::get('/referral-bonus-search', 'User\HomeController@referralBonusSearch')->name('referral.bonus.search');

            // TWO-FACTOR SECURITY
            Route::get('/twostep-security', 'User\HomeController@twoStepSecurity')->name('twostep.security');
            Route::post('twoStep-enable', 'User\HomeController@twoStepEnable')->name('twoStepEnable');
            Route::post('twoStep-disable', 'User\HomeController@twoStepDisable')->name('twoStepDisable');


            Route::get('push-notification-show', 'SiteNotificationController@show')->name('push.notification.show');
            Route::get('push.notification.readAll', 'SiteNotificationController@readAll')->name('push.notification.readAll');
            Route::get('push-notification-readAt/{id}', 'SiteNotificationController@readAt')->name('push.notification.readAt');


            // payout
            Route::get('/withdraw', 'User\HomeController@payoutMoney')->name('payout.money');
            Route::post('/withdraw', 'User\HomeController@payoutMoneyRequest')->name('payout.moneyRequest');
            Route::get('/withdraw/preview', 'User\HomeController@payoutPreview')->name('payout.preview');
            Route::post('/withdraw/preview', 'User\HomeController@payoutRequestSubmit')->name('payout.submit');
            Route::post('/withdraw/paystack/{trx_id}', 'User\HomeController@paystackPayout')->name('payout.submit.paystack');
            Route::post('/withdraw/flutterwave/{trx_id}', 'User\HomeController@flutterwavePayout')->name('payout.submit.flutterwave');
            Route::post('withdraw-bank-list', 'User\HomeController@getBankList')->name('payout.getBankList');
            Route::post('withdraw-bank-from', 'User\HomeController@getBankForm')->name('payout.getBankFrom');


            Route::get('withdraw-history', 'User\HomeController@payoutHistory')->name('payout.history');
            Route::get('withdraw-history-search', 'User\HomeController@payoutHistorySearch')->name('payout.history.search');

       });

        Route::get('/profile', 'User\HomeController@profile')->name('profile');
        Route::post('/updateProfile', 'User\HomeController@updateProfile')->name('updateProfile');
        Route::put('/updateInformation', 'User\HomeController@updateInformation')->name('updateInformation');
        Route::post('/updatePassword', 'User\HomeController@updatePassword')->name('updatePassword');

        Route::post('/verificationSubmit', 'User\HomeController@verificationSubmit')->name('verificationSubmit');
        Route::post('/addressVerification', 'User\HomeController@addressVerification')->name('addressVerification');


        Route::group(['prefix' => 'ticket', 'as' => 'ticket.'], function () {
            Route::get('/', 'User\SupportController@index')->name('list');
            Route::get('/create', 'User\SupportController@create')->name('create');
            Route::post('/create', 'User\SupportController@store')->name('store');
            Route::get('/view/{ticket}', 'User\SupportController@ticketView')->name('view');
            Route::put('/reply/{ticket}', 'User\SupportController@reply')->name('reply');
            Route::get('/download/{ticket}', 'User\SupportController@download')->name('download');
        });


    });
});


Route::group(['prefix' => 'admin', 'as' => 'admin.'], function () {
    Route::get('/', 'Admin\LoginController@showLoginForm')->name('login');
    Route::post('/', 'Admin\LoginController@login')->name('login');
    Route::post('/logout', 'Admin\LoginController@logout')->name('logout');


    Route::get('/password/reset', 'Admin\Auth\ForgotPasswordController@showLinkRequestForm')->name('password.request');
    Route::post('/password/email', 'Admin\Auth\ForgotPasswordController@sendResetLinkEmail')->name('password.email');
    Route::get('/password/reset/{token}', 'Admin\Auth\ResetPasswordController@showResetForm')->name('password.reset');
    Route::post('/password/reset', 'Admin\Auth\ResetPasswordController@reset')->name('password.update');


    Route::get('/403', 'Admin\DashboardController@forbidden')->name('403');

    Route::group(['middleware' => ['auth:admin']], function () {
        Route::get('/dashboard', 'Admin\DashboardController@dashboard')->name('dashboard');

        Route::get('/profile', 'Admin\DashboardController@profile')->name('profile');
        Route::put('/profile', 'Admin\DashboardController@profileUpdate')->name('profileUpdate');
        Route::get('/password', 'Admin\DashboardController@password')->name('password');
        Route::put('/password', 'Admin\DashboardController@passwordUpdate')->name('passwordUpdate');


        Route::get('/identity-form', 'Admin\IdentyVerifyFromController@index')->name('identify-form');
        Route::post('/identity-form', 'Admin\IdentyVerifyFromController@store')->name('identify-form.store');
        Route::post('/identity-form/action', 'Admin\IdentyVerifyFromController@action')->name('identify-form.action');


        /* ====== Transaction Log =====*/
        Route::get('/transaction', 'Admin\LogController@transaction')->name('transaction');
        Route::get('/transaction-search', 'Admin\LogController@transactionSearch')->name('transaction.search');



        /*====Manage Users ====*/
        Route::get('/users', 'Admin\UsersController@index')->name('users');
        Route::get('/users/search', 'Admin\UsersController@search')->name('users.search');
        Route::post('/users-active', 'Admin\UsersController@activeMultiple')->name('user-multiple-active');
        Route::post('/users-inactive', 'Admin\UsersController@inactiveMultiple')->name('user-multiple-inactive');
        Route::get('/user/edit/{id}', 'Admin\UsersController@userEdit')->name('user-edit');
        Route::post('/user/update/{id}', 'Admin\UsersController@userUpdate')->name('user-update');
        Route::post('/user/password/{id}', 'Admin\UsersController@passwordUpdate')->name('userPasswordUpdate');
        Route::post('/user/balance-update/{id}', 'Admin\UsersController@userBalanceUpdate')->name('user-balance-update');

        Route::get('/user/send-email/{id}', 'Admin\UsersController@sendEmail')->name('send-email');
        Route::post('/user/send-email/{id}', 'Admin\UsersController@sendMailUser')->name('user.email-send');
        Route::get('/user/transaction/{id}', 'Admin\UsersController@transaction')->name('user.transaction');
        Route::get('/user/fundLog/{id}', 'Admin\UsersController@funds')->name('user.fundLog');
        Route::get('/user/withdrawLog/{id}', 'Admin\UsersController@payoutLog')->name('user.withdrawal');
        Route::get('/user/referralMember/{id}', 'Admin\UsersController@referralMember')->name('user.referralMember');
        Route::get('/user/commissionLog/{id}', 'Admin\UsersController@commissionLog')->name('user.commissionLog');
        Route::get('/user/ads/view/log/{id}', 'Admin\UsersController@adsViewLog')->name('user.ads.view.log');
        Route::get('/user/ads/view/log/search/{id}', 'Admin\UsersController@adsViewLogSearch')->name('user.ads.view.log.search');
        Route::get('/user/ads/list/{id}', 'Admin\UsersController@adsList')->name('user.ads.list');
        Route::get('/user/ads/list/search/{id}', 'Admin\UsersController@adsListSearch')->name('user.ads.list.search');
        Route::post('/admin/login/as/user/{id}', 'Admin\UsersController@loginAsUser')->name('login-as-user');

        Route::get('users/kyc/pending', 'Admin\UsersController@kycPendingList')->name('kyc.users.pending');
        Route::get('users/kyc', 'Admin\UsersController@kycList')->name('kyc.users');
        Route::put('users/kycAction/{id}', 'Admin\UsersController@kycAction')->name('users.Kyc.action');
        Route::get('user/{user}/kyc', 'Admin\UsersController@userKycHistory')->name('user.userKycHistory');

        Route::get('/email-send', 'Admin\UsersController@emailToUsers')->name('email-send');
        Route::post('/email-send', 'Admin\UsersController@sendEmailToUsers')->name('email-send.store');




        /*=====Payment Log=====*/
        Route::get('payment-methods', 'Admin\PaymentMethodController@index')->name('payment.methods');
        Route::post('payment-methods/deactivate', 'Admin\PaymentMethodController@deactivate')->name('payment.methods.deactivate');
        Route::get('payment-methods/deactivate', 'Admin\PaymentMethodController@deactivate')->name('payment.methods.deactivate');
        Route::post('sort-payment-methods', 'Admin\PaymentMethodController@sortPaymentMethods')->name('sort.payment.methods');
        Route::get('payment-methods/edit/{id}', 'Admin\PaymentMethodController@edit')->name('edit.payment.methods');
        Route::put('payment-methods/update/{id}', 'Admin\PaymentMethodController@update')->name('update.payment.methods');


        // Manual Methods
        Route::get('payment-methods/manual', 'Admin\ManualGatewayController@index')->name('deposit.manual.index');
        Route::get('payment-methods/manual/new', 'Admin\ManualGatewayController@create')->name('deposit.manual.create');
        Route::post('payment-methods/manual/new', 'Admin\ManualGatewayController@store')->name('deposit.manual.store');
        Route::get('payment-methods/manual/edit/{id}', 'Admin\ManualGatewayController@edit')->name('deposit.manual.edit');
        Route::put('payment-methods/manual/update/{id}', 'Admin\ManualGatewayController@update')->name('deposit.manual.update');


        Route::get('payment/pending', 'Admin\PaymentLogController@pending')->name('payment.pending');
        Route::put('payment/action/{id}', 'Admin\PaymentLogController@action')->name('payment.action');
        Route::get('payment/log', 'Admin\PaymentLogController@index')->name('payment.log');
        Route::get('payment/search', 'Admin\PaymentLogController@search')->name('payment.search');



        /*==========Payout Settings============*/
        Route::get('/withdraw-method', 'Admin\PayoutGatewayController@index')->name('payout-method');
        Route::get('/withdraw-method/create', 'Admin\PayoutGatewayController@create')->name('payout-method.create');
        Route::post('/withdraw-method/create', 'Admin\PayoutGatewayController@store')->name('payout-method.store');
        Route::get('/withdraw-method/{id}', 'Admin\PayoutGatewayController@edit')->name('payout-method.edit');
        Route::put('/withdraw-method/{id}', 'Admin\PayoutGatewayController@update')->name('payout-method.update');

        Route::get('/withdraw-log', 'Admin\PayoutRecordController@index')->name('payout-log');
        Route::get('/withdraw-log/search', 'Admin\PayoutRecordController@search')->name('payout-log.search');
        Route::get('/withdraw-request', 'Admin\PayoutRecordController@request')->name('payout-request');
        Route::get('/withdraw-view/{id}', 'Admin\PayoutRecordController@view')->name('payout-view');
        Route::post('/withdraw-confirm/{id}', 'Admin\PayoutRecordController@payoutConfirm')->name('payout-confirm');
        Route::post('/withdraw-cancel/{id}', 'Admin\PayoutRecordController@payoutCancel')->name('payout-cancel');


        /* ===== Support Ticket ====*/
        Route::get('tickets/{status?}', 'Admin\TicketController@tickets')->name('ticket');
        Route::get('tickets/view/{id}', 'Admin\TicketController@ticketReply')->name('ticket.view');
        Route::put('ticket/reply/{id}', 'Admin\TicketController@ticketReplySend')->name('ticket.reply');
        Route::get('ticket/download/{ticket}', 'Admin\TicketController@ticketDownload')->name('ticket.download');
        Route::post('ticket/delete', 'Admin\TicketController@ticketDelete')->name('ticket.delete');

        /* ===== Subscriber =====*/
        Route::get('subscriber', 'Admin\SubscriberController@index')->name('subscriber.index');
        Route::post('subscriber/remove', 'Admin\SubscriberController@remove')->name('subscriber.remove');
        Route::get('subscriber/send-email', 'Admin\SubscriberController@sendEmailForm')->name('subscriber.sendEmail');
        Route::post('subscriber/send-email', 'Admin\SubscriberController@sendEmail')->name('subscriber.mail');



        /* ===== website controls =====*/
        Route::any('/basic-controls', 'Admin\BasicController@index')->name('basic-controls');
        Route::post('/basic-controls', 'Admin\BasicController@updateConfigure')->name('basic-controls.update');

        Route::any('/email-controls', 'Admin\EmailTemplateController@emailControl')->name('email-controls');
        Route::post('/email-controls', 'Admin\EmailTemplateController@emailConfigure')->name('email-controls.update');
        Route::post('/email-controls/action', 'Admin\EmailTemplateController@emailControlAction')->name('email-controls.action');
        Route::post('/email/test', 'Admin\EmailTemplateController@testEmail')->name('testEmail');

        Route::get('/email-template', 'Admin\EmailTemplateController@show')->name('email-template.show');
        Route::get('/email-template/edit/{id}', 'Admin\EmailTemplateController@edit')->name('email-template.edit');
        Route::post('/email-template/update/{id}', 'Admin\EmailTemplateController@update')->name('email-template.update');

        /*========Sms control ========*/
        Route::match(['get', 'post'], '/sms-controls', 'Admin\SmsTemplateController@smsConfig')->name('sms.config');
        Route::post('/sms-controls/action', 'Admin\SmsTemplateController@smsControlAction')->name('sms-controls.action');
        Route::get('/sms-template', 'Admin\SmsTemplateController@show')->name('sms-template');
        Route::get('/sms-template/edit/{id}', 'Admin\SmsTemplateController@edit')->name('sms-template.edit');
        Route::post('/sms-template/update/{id}', 'Admin\SmsTemplateController@update')->name('sms-template.update');

        Route::get('/notify-config', 'Admin\NotifyController@notifyConfig')->name('notify-config');
        Route::post('/notify-config', 'Admin\NotifyController@notifyConfigUpdate')->name('notify-config.update');
        Route::get('/notify-template', 'Admin\NotifyController@show')->name('notify-template.show');
        Route::get('/notify-template/edit/{id}', 'Admin\NotifyController@edit')->name('notify-template.edit');
        Route::post('/notify-template/update/{id}', 'Admin\NotifyController@update')->name('notify-template.update');


        /* ===== ADMIN Language SETTINGS ===== */
        Route::get('language', 'Admin\LanguageController@index')->name('language.index');
        Route::get('language/create', 'Admin\LanguageController@create')->name('language.create');
        Route::post('language/create', 'Admin\LanguageController@store')->name('language.store');
        Route::get('language/{language}', 'Admin\LanguageController@edit')->name('language.edit');
        Route::put('language/{language}', 'Admin\LanguageController@update')->name('language.update');
        Route::delete('language/{language}', 'Admin\LanguageController@delete')->name('language.delete');
        Route::get('/language/keyword/{id}', 'Admin\LanguageController@keywordEdit')->name('language.keywordEdit');
        Route::put('/language/keyword/{id}', 'Admin\LanguageController@keywordUpdate')->name('language.keywordUpdate');
        Route::post('/language/importJson', 'Admin\LanguageController@importJson')->name('language.importJson');
        Route::post('store-key/{id}', 'Admin\LanguageController@storeKey')->name('language.storeKey');
        Route::put('update-key/{id}', 'Admin\LanguageController@updateKey')->name('language.updateKey');
        Route::delete('delete-key/{id}', 'Admin\LanguageController@deleteKey')->name('language.deleteKey');



        Route::get('/logo-seo', 'Admin\BasicController@logoSeo')->name('logo-seo');
        Route::put('/logoUpdate', 'Admin\BasicController@logoUpdate')->name('logoUpdate');
        Route::put('/seoUpdate', 'Admin\BasicController@seoUpdate')->name('seoUpdate');


        /* ===== ADMIN TEMPLATE SETTINGS ===== */
        Route::get('template/{section}', 'Admin\TemplateController@show')->name('template.show');
        Route::put('template/{section}/{language}', 'Admin\TemplateController@update')->name('template.update');
        Route::get('contents/{content}', 'Admin\ContentController@index')->name('content.index');
        Route::get('content-create/{content}', 'Admin\ContentController@create')->name('content.create');
        Route::put('content-create/{content}/{language?}', 'Admin\ContentController@store')->name('content.store');
        Route::get('content-show/{content}/{name?}', 'Admin\ContentController@show')->name('content.show');
        Route::put('content-update/{content}/{language?}', 'Admin\ContentController@update')->name('content.update');
        Route::delete('contents/{id}', 'Admin\ContentController@contentDelete')->name('content.delete');


        Route::get('push-notification-show', 'SiteNotificationController@showByAdmin')->name('push.notification.show');
        Route::get('push.notification.readAll', 'SiteNotificationController@readAllByAdmin')->name('push.notification.readAll');
        Route::get('push-notification-readAt/{id}', 'SiteNotificationController@readAt')->name('push.notification.readAt');
        Route::match(['get', 'post'], 'pusher-config', 'SiteNotificationController@pusherConfig')->name('pusher.config');


        /* ======== Plugins =======*/
        Route::get('/plugin-config', 'Admin\BasicController@pluginConfig')->name('plugin.config');
        Route::match(['get', 'post'], 'tawk-config', 'Admin\BasicController@tawkConfig')->name('tawk.control');
        Route::match(['get', 'post'], 'fb-messenger-config', 'Admin\BasicController@fbMessengerConfig')->name('fb.messenger.control');
        Route::match(['get', 'post'], 'google-recaptcha', 'Admin\BasicController@googleRecaptchaConfig')->name('google.recaptcha.control');
        Route::match(['get', 'post'], 'google-analytics', 'Admin\BasicController@googleAnalyticsConfig')->name('google.analytics.control');


        /* ======== Social Login ======= */
        Route::get('social-login', 'Admin\BasicController@sociaLoginConfig')->name('social.login.config');
        Route::match(['get', 'post'], 'google-login-config', 'Admin\BasicController@googleLoginConfig')->name('google.login.control');
        Route::match(['get', 'post'], 'facebook-login-config', 'Admin\BasicController@facebookLoginConfig')->name('facebook.login.control');
        Route::match(['get', 'post'], 'github-login-config', 'Admin\BasicController@githubLoginConfig')->name('github.login.control');


        /* ===== Admin Blog Management ===== */
        Route::get('/blog/category', 'Admin\BlogController@categoryList')->name('blogCategory');
        Route::get('/blog/category/create', 'Admin\BlogController@blogCategoryCreate')->name('blogCategoryCreate');
        Route::post('/blog/category/store/{language?}', 'Admin\BlogController@blogCategoryStore')->name('blogCategoryStore');
        Route::get('/blog/category/edit/{id}', 'Admin\BlogController@blogCategoryEdit')->name('blogCategoryEdit');
        Route::put('/blog/category/update/{id}/{language?}', 'Admin\BlogController@blogCategoryUpdate')->name('blogCategoryUpdate');
        Route::delete('/blog/category/delete/{id}', 'Admin\BlogController@blogCategoryDelete')->name('blogCategoryDelete');

        Route::get('/blog/list', 'Admin\BlogController@blogList')->name('blogList');
        Route::get('/blog/create', 'Admin\BlogController@blogCreate')->name('blogCreate');
        Route::post('/blog/store/{language?}', 'Admin\BlogController@blogStore')->name('blogStore');
        Route::get('/blog/edit/{id}', 'Admin\BlogController@blogEdit')->name('blogEdit');
        Route::put('/blog/update/{id}/{language?}', 'Admin\BlogController@blogUpdate')->name('blogUpdate');
        Route::delete('/blog/delete/{id}', 'Admin\BlogController@blogDelete')->name('blogDelete');



        /*====== Admin Manage Plan =======*/
        Route::get('/plan-list', 'Admin\ManagePlanController@plan')->name('planList');
        Route::get('/plan-create', 'Admin\ManagePlanController@planCreate')->name('planCreate');
        Route::post('/plan-store/{language?}', 'Admin\ManagePlanController@planStore')->name('planStore');
        Route::get('/plan-edit/{id}', 'Admin\ManagePlanController@planEdit')->name('planEdit');
        Route::put('/plan-update/{id}/{language?}', 'Admin\ManagePlanController@planUpdate')->name('planUpdate');
        Route::delete('/plan-delete/{id}', 'Admin\ManagePlanController@planDelete')->name('planDelete');


        /*====== Refferel Commission =======*/
        Route::get('/referral-commission', 'Admin\ManagePlanController@referralCommission')->name('referral-commission');
        Route::post('/referral-commission', 'Admin\ManagePlanController@referralCommissionStore')->name('referral-commission.store');
        Route::post('/referral-commission/action', 'Admin\ManagePlanController@referralCommissionAction')->name('referral-commission.action');

        /* ===== Refferel Commission Log ===== */
        Route::get('/commissions', 'Admin\LogController@commissions')->name('commissions');
        Route::get('/commissions-search', 'Admin\LogController@commissionsSearch')->name('commissions.search');

        /* ===== Refferel Commission Log ===== */
        Route::get('/ads/view/log', 'Admin\LogController@adViewLog')->name('ads.view.log');
        Route::get('/ads/view/log/search', 'Admin\LogController@adViewLogSearch')->name('ads.view.log.search');


        /* ===== Plan Purchased History ===== */
        Route::get('/plan/purchased/history', 'Admin\ManagePlanController@planHistoryLog')->name('plan.log');
        Route::get('/plan/purchased/history/search', 'Admin\ManagePlanController@planHistoryLogSearch')->name('plan.log.search');

        /* ===== Manage Advertisement Settings ===== */
        Route::get('/ads/setting', 'Admin\ManagePlanController@advertisementSettings')->name('advertisement.settings');
        Route::post('/store/ads/setting', 'Admin\ManagePlanController@storeAdvertisementSettings')->name('store.advertisement.settings');

        Route::get('manage/ads', 'Admin\ManagePlanController@manageAdvertisement')->name('manage.advertisement');
        Route::get('create/ads', 'Admin\ManagePlanController@createAdvertisement')->name('create.advertisement');
        Route::get('search/ads', 'Admin\ManagePlanController@searchAdvertisement')->name('search.advertisement');
        Route::post('store/ads', 'Admin\ManagePlanController@storeAdvertisement')->name('advertisement.store');
        Route::get('edit/ads/{id}', 'Admin\ManagePlanController@editAdvertisement')->name('edit.advertisement');
        Route::put('update/ads/{id}', 'Admin\ManagePlanController@updateAdvertisement')->name('update.advertisement');
        Route::delete('delete/ads/{id}', 'Admin\ManagePlanController@deleteAdvertisement')->name('delete.advertisement');

    });


});


Route::match(['get', 'post'], 'success', 'PaymentController@success')->name('success');
Route::match(['get', 'post'], 'failed', 'PaymentController@failed')->name('failed');
Route::match(['get', 'post'], 'payment/{code}/{trx?}/{type?}', 'PaymentController@gatewayIpn')->name('ipn');
Route::post('/khalti/payment/verify/{trx}', 'khaltiPaymentController@verifyPayment')->name('khalti.verifyPayment');
Route::post('/khalti/payment/store','khaltiPaymentController@storePayment')->name('khalti.storePayment');


Route::get('/language/{code?}', 'FrontendController@language')->name('language');


//--social login with socialite--
Route::get('auth/social', 'Auth\LoginController@showLoginForm')->name('social.login');
Route::get('oauth/{driver}', 'Auth\LoginController@redirectToProvider')->name('social.oauth');
Route::get('oauth/{driver}/callback', 'Auth\LoginController@handleProviderCallback')->name('social.callback');


//--blog--
Route::get('/blog', 'FrontendController@blog')->name('blog');
Route::get('/blog-details/{slug}/{id}', 'FrontendController@blogDetails')->name('blogDetails');
Route::get('/blog/search', 'FrontendController@blogSearch')->name('blogSearch');
Route::get('/blog/category/{slug}/{id}', 'FrontendController@CategoryWiseBlog')->name('CategoryWiseBlog');
Route::get('/category', 'FrontendController@category')->name('category');
Route::get('/blog-details/{slug}/{id}', 'FrontendController@blogDetails')->name('blogDetails');

Route::get('/', 'FrontendController@index')->name('home');
Route::get('/about', 'FrontendController@about')->name('about');
Route::get('/plan', 'FrontendController@planList')->name('plan');
Route::get('/faq', 'FrontendController@faq')->name('faq');

Route::get('/contact', 'FrontendController@contact')->name('contact');
Route::post('/contact', 'FrontendController@contactSend')->name('contact.send');

Route::post('/subscribe', 'FrontendController@subscribe')->name('subscribe');

Route::get('/{getLink}/{content_id}', 'FrontendController@getLink')->name('getLink');

Route::get('/{template?}', 'FrontendController@getTemplate')->name('getTemplate');



